# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'ImageDetectionResults',
    'ImageDetectionResultsItem',
    'ImageSnapshot',
    'ImageTag',
    'InstanceCpuMemory',
    'InstanceEipAddress',
    'InstanceImage',
    'InstanceKeyPair',
    'InstanceOperationSystem',
    'InstancePlacement',
    'InstancePrimaryNetworkInterface',
    'InstanceSecondaryNetworkInterface',
    'InstanceSystemVolume',
    'InstanceTag',
    'GetImageDetectionResultsResult',
    'GetImageDetectionResultsItemResult',
    'GetImageSnapshotResult',
    'GetImageTagResult',
    'GetInstanceCpuMemoryResult',
    'GetInstanceEipAddressResult',
    'GetInstanceImageResult',
    'GetInstanceKeyPairResult',
    'GetInstanceOperationSystemResult',
    'GetInstancePlacementResult',
    'GetInstancePrimaryNetworkInterfaceResult',
    'GetInstanceSecondaryNetworkInterfaceResult',
    'GetInstanceSystemVolumeResult',
    'GetInstanceTagResult',
]

@pulumi.output_type
class ImageDetectionResults(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "detectionStatus":
            suggest = "detection_status"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ImageDetectionResults. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ImageDetectionResults.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ImageDetectionResults.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 detection_status: Optional[builtins.str] = None,
                 items: Optional[Sequence['outputs.ImageDetectionResultsItem']] = None):
        """
        :param builtins.str detection_status: 检测状态。可以选择Finished（已完成）、Processing（处理中）类型。
        """
        if detection_status is not None:
            pulumi.set(__self__, "detection_status", detection_status)
        if items is not None:
            pulumi.set(__self__, "items", items)

    @property
    @pulumi.getter(name="detectionStatus")
    def detection_status(self) -> Optional[builtins.str]:
        """
        检测状态。可以选择Finished（已完成）、Processing（处理中）类型。
        """
        return pulumi.get(self, "detection_status")

    @property
    @pulumi.getter
    def items(self) -> Optional[Sequence['outputs.ImageDetectionResultsItem']]:
        return pulumi.get(self, "items")


@pulumi.output_type
class ImageDetectionResultsItem(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "riskCode":
            suggest = "risk_code"
        elif key == "riskLevel":
            suggest = "risk_level"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ImageDetectionResultsItem. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ImageDetectionResultsItem.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ImageDetectionResultsItem.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 name: Optional[builtins.str] = None,
                 result: Optional[builtins.str] = None,
                 risk_code: Optional[builtins.str] = None,
                 risk_level: Optional[builtins.str] = None):
        """
        :param builtins.str name: 检测项名称。
        :param builtins.str result: 该检测项对应结果。
        :param builtins.str risk_code: 风险描述码。
        :param builtins.str risk_level: 风险等级。若该参数返回值为空，表示无风险。
        """
        if name is not None:
            pulumi.set(__self__, "name", name)
        if result is not None:
            pulumi.set(__self__, "result", result)
        if risk_code is not None:
            pulumi.set(__self__, "risk_code", risk_code)
        if risk_level is not None:
            pulumi.set(__self__, "risk_level", risk_level)

    @property
    @pulumi.getter
    def name(self) -> Optional[builtins.str]:
        """
        检测项名称。
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def result(self) -> Optional[builtins.str]:
        """
        该检测项对应结果。
        """
        return pulumi.get(self, "result")

    @property
    @pulumi.getter(name="riskCode")
    def risk_code(self) -> Optional[builtins.str]:
        """
        风险描述码。
        """
        return pulumi.get(self, "risk_code")

    @property
    @pulumi.getter(name="riskLevel")
    def risk_level(self) -> Optional[builtins.str]:
        """
        风险等级。若该参数返回值为空，表示无风险。
        """
        return pulumi.get(self, "risk_level")


@pulumi.output_type
class ImageSnapshot(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "snapshotId":
            suggest = "snapshot_id"
        elif key == "volumeKind":
            suggest = "volume_kind"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ImageSnapshot. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ImageSnapshot.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ImageSnapshot.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 size: Optional[builtins.int] = None,
                 snapshot_id: Optional[builtins.str] = None,
                 volume_kind: Optional[builtins.str] = None):
        """
        :param builtins.int size: 快照大小。单位为GiB。
        :param builtins.str snapshot_id: 快照ID。
        :param builtins.str volume_kind: 云盘种类。system：系统盘。data：数据盘。
        """
        if size is not None:
            pulumi.set(__self__, "size", size)
        if snapshot_id is not None:
            pulumi.set(__self__, "snapshot_id", snapshot_id)
        if volume_kind is not None:
            pulumi.set(__self__, "volume_kind", volume_kind)

    @property
    @pulumi.getter
    def size(self) -> Optional[builtins.int]:
        """
        快照大小。单位为GiB。
        """
        return pulumi.get(self, "size")

    @property
    @pulumi.getter(name="snapshotId")
    def snapshot_id(self) -> Optional[builtins.str]:
        """
        快照ID。
        """
        return pulumi.get(self, "snapshot_id")

    @property
    @pulumi.getter(name="volumeKind")
    def volume_kind(self) -> Optional[builtins.str]:
        """
        云盘种类。system：系统盘。data：数据盘。
        """
        return pulumi.get(self, "volume_kind")


@pulumi.output_type
class ImageTag(dict):
    def __init__(__self__, *,
                 key: Optional[builtins.str] = None,
                 value: Optional[builtins.str] = None):
        """
        :param builtins.str key: 镜像标签的标签键。
        :param builtins.str value: 镜像标签的值。
        """
        if key is not None:
            pulumi.set(__self__, "key", key)
        if value is not None:
            pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> Optional[builtins.str]:
        """
        镜像标签的标签键。
        """
        return pulumi.get(self, "key")

    @property
    @pulumi.getter
    def value(self) -> Optional[builtins.str]:
        """
        镜像标签的值。
        """
        return pulumi.get(self, "value")


@pulumi.output_type
class InstanceCpuMemory(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "coreCount":
            suggest = "core_count"
        elif key == "cpuNumber":
            suggest = "cpu_number"
        elif key == "memorySize":
            suggest = "memory_size"
        elif key == "threadsPerCore":
            suggest = "threads_per_core"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in InstanceCpuMemory. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        InstanceCpuMemory.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        InstanceCpuMemory.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 core_count: Optional[builtins.int] = None,
                 cpu_number: Optional[builtins.int] = None,
                 memory_size: Optional[builtins.int] = None,
                 threads_per_core: Optional[builtins.int] = None):
        """
        :param builtins.int core_count: 实例的核数。
        :param builtins.int cpu_number: 实例的CPU数量。
        :param builtins.int memory_size: 实例的内存大小，单位MB。
        :param builtins.int threads_per_core: 实例的每核线程数。
        """
        if core_count is not None:
            pulumi.set(__self__, "core_count", core_count)
        if cpu_number is not None:
            pulumi.set(__self__, "cpu_number", cpu_number)
        if memory_size is not None:
            pulumi.set(__self__, "memory_size", memory_size)
        if threads_per_core is not None:
            pulumi.set(__self__, "threads_per_core", threads_per_core)

    @property
    @pulumi.getter(name="coreCount")
    def core_count(self) -> Optional[builtins.int]:
        """
        实例的核数。
        """
        return pulumi.get(self, "core_count")

    @property
    @pulumi.getter(name="cpuNumber")
    def cpu_number(self) -> Optional[builtins.int]:
        """
        实例的CPU数量。
        """
        return pulumi.get(self, "cpu_number")

    @property
    @pulumi.getter(name="memorySize")
    def memory_size(self) -> Optional[builtins.int]:
        """
        实例的内存大小，单位MB。
        """
        return pulumi.get(self, "memory_size")

    @property
    @pulumi.getter(name="threadsPerCore")
    def threads_per_core(self) -> Optional[builtins.int]:
        """
        实例的每核线程数。
        """
        return pulumi.get(self, "threads_per_core")


@pulumi.output_type
class InstanceEipAddress(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "allocationId":
            suggest = "allocation_id"
        elif key == "bandwidthMbps":
            suggest = "bandwidth_mbps"
        elif key == "bandwidthPackageId":
            suggest = "bandwidth_package_id"
        elif key == "chargeType":
            suggest = "charge_type"
        elif key == "ipAddress":
            suggest = "ip_address"
        elif key == "releaseWithInstance":
            suggest = "release_with_instance"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in InstanceEipAddress. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        InstanceEipAddress.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        InstanceEipAddress.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 allocation_id: Optional[builtins.str] = None,
                 bandwidth_mbps: Optional[builtins.int] = None,
                 bandwidth_package_id: Optional[builtins.str] = None,
                 charge_type: Optional[builtins.str] = None,
                 ip_address: Optional[builtins.str] = None,
                 isp: Optional[builtins.str] = None,
                 release_with_instance: Optional[builtins.bool] = None):
        """
        :param builtins.str allocation_id: 实例的分配ID。
        :param builtins.int bandwidth_mbps: 公网IP的带宽上限，默认值为1，单位：Mbps。
                   - `ChargeType`传入`PayByBandwidth`：取值范围1～500。
                   - `ChargeType`传入`PayByTraffic`：取值范围1～200。
        :param builtins.str bandwidth_package_id: 共享带宽包的ID，表示将公网IP加入到共享带宽包。
                   - 您可以调用[DescribeBandwidthPackages](https://www.volcengine.com/docs/6623/100685)接口，查询共享带宽包的ID。
                   - 公网IP加入到共享带宽包必须同时满足如下条件：
                     - 二者的安全防护类型相同。
                     - 二者的地域相同。
                     - 公网IP的计费方式必须是按量计费。
                     - 共享带宽包为IPv4类型。
        :param builtins.str charge_type: 公网IP的计费方式，取值：
                   - PayByBandwidth（默认）：按量计费-按带宽上限计费。
                   - PayByTraffic：按量计费-按实际流量计费。
                   - PrePaid：包年包月。
                 
                 **提示:**
                 实例的计费类型`InstanceChargeType`取值为`PostPaid`时，该参数取值不能为`PrePaid`。
        :param builtins.str ip_address: 实例的IP地址。
        :param builtins.str isp: 公网IP的线路类型，默认为BGP。取值：
                   - BGP：BGP（多线）。
                   - 若您的账号已申请并开通了静态单线权限，则可传入如下取值：
                     - ChinaMobile：中国移动静态单线。
                     - ChinaTelecom：中国电信静态单线。
                     - ChinaUnicom：中国联通静态单线。
                   - 若您的账号已申请并开通了BGP单线权限，则可传入SingleLine_BGP。
                   - 若您的账号已申请并开通了静态BGP权限，则可传入Static_BGP。
        :param builtins.bool release_with_instance: 实例是否随实例释放。
        """
        if allocation_id is not None:
            pulumi.set(__self__, "allocation_id", allocation_id)
        if bandwidth_mbps is not None:
            pulumi.set(__self__, "bandwidth_mbps", bandwidth_mbps)
        if bandwidth_package_id is not None:
            pulumi.set(__self__, "bandwidth_package_id", bandwidth_package_id)
        if charge_type is not None:
            pulumi.set(__self__, "charge_type", charge_type)
        if ip_address is not None:
            pulumi.set(__self__, "ip_address", ip_address)
        if isp is not None:
            pulumi.set(__self__, "isp", isp)
        if release_with_instance is not None:
            pulumi.set(__self__, "release_with_instance", release_with_instance)

    @property
    @pulumi.getter(name="allocationId")
    def allocation_id(self) -> Optional[builtins.str]:
        """
        实例的分配ID。
        """
        return pulumi.get(self, "allocation_id")

    @property
    @pulumi.getter(name="bandwidthMbps")
    def bandwidth_mbps(self) -> Optional[builtins.int]:
        """
        公网IP的带宽上限，默认值为1，单位：Mbps。
            - `ChargeType`传入`PayByBandwidth`：取值范围1～500。
            - `ChargeType`传入`PayByTraffic`：取值范围1～200。
        """
        return pulumi.get(self, "bandwidth_mbps")

    @property
    @pulumi.getter(name="bandwidthPackageId")
    def bandwidth_package_id(self) -> Optional[builtins.str]:
        """
        共享带宽包的ID，表示将公网IP加入到共享带宽包。
            - 您可以调用[DescribeBandwidthPackages](https://www.volcengine.com/docs/6623/100685)接口，查询共享带宽包的ID。
            - 公网IP加入到共享带宽包必须同时满足如下条件：
              - 二者的安全防护类型相同。
              - 二者的地域相同。
              - 公网IP的计费方式必须是按量计费。
              - 共享带宽包为IPv4类型。
        """
        return pulumi.get(self, "bandwidth_package_id")

    @property
    @pulumi.getter(name="chargeType")
    def charge_type(self) -> Optional[builtins.str]:
        """
        公网IP的计费方式，取值：
            - PayByBandwidth（默认）：按量计费-按带宽上限计费。
            - PayByTraffic：按量计费-按实际流量计费。
            - PrePaid：包年包月。
          
          **提示:**
          实例的计费类型`InstanceChargeType`取值为`PostPaid`时，该参数取值不能为`PrePaid`。
        """
        return pulumi.get(self, "charge_type")

    @property
    @pulumi.getter(name="ipAddress")
    def ip_address(self) -> Optional[builtins.str]:
        """
        实例的IP地址。
        """
        return pulumi.get(self, "ip_address")

    @property
    @pulumi.getter
    def isp(self) -> Optional[builtins.str]:
        """
        公网IP的线路类型，默认为BGP。取值：
            - BGP：BGP（多线）。
            - 若您的账号已申请并开通了静态单线权限，则可传入如下取值：
              - ChinaMobile：中国移动静态单线。
              - ChinaTelecom：中国电信静态单线。
              - ChinaUnicom：中国联通静态单线。
            - 若您的账号已申请并开通了BGP单线权限，则可传入SingleLine_BGP。
            - 若您的账号已申请并开通了静态BGP权限，则可传入Static_BGP。
        """
        return pulumi.get(self, "isp")

    @property
    @pulumi.getter(name="releaseWithInstance")
    def release_with_instance(self) -> Optional[builtins.bool]:
        """
        实例是否随实例释放。
        """
        return pulumi.get(self, "release_with_instance")


@pulumi.output_type
class InstanceImage(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "imageId":
            suggest = "image_id"
        elif key == "imageReleaseVersion":
            suggest = "image_release_version"
        elif key == "keepImageCredential":
            suggest = "keep_image_credential"
        elif key == "securityEnhancementStrategy":
            suggest = "security_enhancement_strategy"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in InstanceImage. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        InstanceImage.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        InstanceImage.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 image_id: builtins.str,
                 image_release_version: Optional[builtins.str] = None,
                 keep_image_credential: Optional[builtins.bool] = None,
                 security_enhancement_strategy: Optional[builtins.str] = None):
        """
        :param builtins.str image_id: 实例的镜像ID。
        :param builtins.str image_release_version: 实例的镜像发布版本。
        :param builtins.bool keep_image_credential: 实例是否保留镜像凭证。
        :param builtins.str security_enhancement_strategy: 实例的安全增强策略。Active：开启安全加固，仅对公共镜像生效。InActive：关闭安全加固，对所有镜像生效。
        """
        pulumi.set(__self__, "image_id", image_id)
        if image_release_version is not None:
            pulumi.set(__self__, "image_release_version", image_release_version)
        if keep_image_credential is not None:
            pulumi.set(__self__, "keep_image_credential", keep_image_credential)
        if security_enhancement_strategy is not None:
            pulumi.set(__self__, "security_enhancement_strategy", security_enhancement_strategy)

    @property
    @pulumi.getter(name="imageId")
    def image_id(self) -> builtins.str:
        """
        实例的镜像ID。
        """
        return pulumi.get(self, "image_id")

    @property
    @pulumi.getter(name="imageReleaseVersion")
    def image_release_version(self) -> Optional[builtins.str]:
        """
        实例的镜像发布版本。
        """
        return pulumi.get(self, "image_release_version")

    @property
    @pulumi.getter(name="keepImageCredential")
    def keep_image_credential(self) -> Optional[builtins.bool]:
        """
        实例是否保留镜像凭证。
        """
        return pulumi.get(self, "keep_image_credential")

    @property
    @pulumi.getter(name="securityEnhancementStrategy")
    def security_enhancement_strategy(self) -> Optional[builtins.str]:
        """
        实例的安全增强策略。Active：开启安全加固，仅对公共镜像生效。InActive：关闭安全加固，对所有镜像生效。
        """
        return pulumi.get(self, "security_enhancement_strategy")


@pulumi.output_type
class InstanceKeyPair(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "keyPairId":
            suggest = "key_pair_id"
        elif key == "keyPairName":
            suggest = "key_pair_name"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in InstanceKeyPair. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        InstanceKeyPair.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        InstanceKeyPair.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 key_pair_id: Optional[builtins.str] = None,
                 key_pair_name: Optional[builtins.str] = None):
        """
        :param builtins.str key_pair_id: 实例的公钥。
        :param builtins.str key_pair_name: 实例的密钥对名称。
        """
        if key_pair_id is not None:
            pulumi.set(__self__, "key_pair_id", key_pair_id)
        if key_pair_name is not None:
            pulumi.set(__self__, "key_pair_name", key_pair_name)

    @property
    @pulumi.getter(name="keyPairId")
    def key_pair_id(self) -> Optional[builtins.str]:
        """
        实例的公钥。
        """
        return pulumi.get(self, "key_pair_id")

    @property
    @pulumi.getter(name="keyPairName")
    def key_pair_name(self) -> Optional[builtins.str]:
        """
        实例的密钥对名称。
        """
        return pulumi.get(self, "key_pair_name")


@pulumi.output_type
class InstanceOperationSystem(dict):
    def __init__(__self__, *,
                 name: Optional[builtins.str] = None,
                 type: Optional[builtins.str] = None):
        """
        :param builtins.str name: 实例的操作系统名称。
        :param builtins.str type: 实例的操作系统类型。Linux：Linux系统。Windows：Windows系统。
        """
        if name is not None:
            pulumi.set(__self__, "name", name)
        if type is not None:
            pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter
    def name(self) -> Optional[builtins.str]:
        """
        实例的操作系统名称。
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def type(self) -> Optional[builtins.str]:
        """
        实例的操作系统类型。Linux：Linux系统。Windows：Windows系统。
        """
        return pulumi.get(self, "type")


@pulumi.output_type
class InstancePlacement(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "dedicatedHostClusterId":
            suggest = "dedicated_host_cluster_id"
        elif key == "dedicatedHostId":
            suggest = "dedicated_host_id"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in InstancePlacement. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        InstancePlacement.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        InstancePlacement.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 affinity: Optional[builtins.str] = None,
                 dedicated_host_cluster_id: Optional[builtins.str] = None,
                 dedicated_host_id: Optional[builtins.str] = None,
                 tenancy: Optional[builtins.str] = None):
        """
        :param builtins.str affinity: 针对节省停机模式的ECS实例，停止后会释放部分资源，本参数用于查看ECS实例重新启动时是否仍固定部署在原宿主机上。取值：Host：启用节省停机模式的实例重新启动时，仍会部署在原宿主机上。Default（默认）：启用节省停机模式的实例重新启动时，会优先迁移到支持自动部署的宿主机；若支持自动部署的宿主机资源不足，则在原宿主机上进行启动。
        :param builtins.str dedicated_host_cluster_id: 实例的专用主机集群ID。
        :param builtins.str dedicated_host_id: 实例的专用主机ID。
        :param builtins.str tenancy: 是否在专有宿主机上创建实例，取值：Default（默认）：创建普通云服务器实例。Host：创建专有宿主机实例。若您不指定DedicatedHostId，则由系统自动选择专有宿主机放置实例
        """
        if affinity is not None:
            pulumi.set(__self__, "affinity", affinity)
        if dedicated_host_cluster_id is not None:
            pulumi.set(__self__, "dedicated_host_cluster_id", dedicated_host_cluster_id)
        if dedicated_host_id is not None:
            pulumi.set(__self__, "dedicated_host_id", dedicated_host_id)
        if tenancy is not None:
            pulumi.set(__self__, "tenancy", tenancy)

    @property
    @pulumi.getter
    def affinity(self) -> Optional[builtins.str]:
        """
        针对节省停机模式的ECS实例，停止后会释放部分资源，本参数用于查看ECS实例重新启动时是否仍固定部署在原宿主机上。取值：Host：启用节省停机模式的实例重新启动时，仍会部署在原宿主机上。Default（默认）：启用节省停机模式的实例重新启动时，会优先迁移到支持自动部署的宿主机；若支持自动部署的宿主机资源不足，则在原宿主机上进行启动。
        """
        return pulumi.get(self, "affinity")

    @property
    @pulumi.getter(name="dedicatedHostClusterId")
    def dedicated_host_cluster_id(self) -> Optional[builtins.str]:
        """
        实例的专用主机集群ID。
        """
        return pulumi.get(self, "dedicated_host_cluster_id")

    @property
    @pulumi.getter(name="dedicatedHostId")
    def dedicated_host_id(self) -> Optional[builtins.str]:
        """
        实例的专用主机ID。
        """
        return pulumi.get(self, "dedicated_host_id")

    @property
    @pulumi.getter
    def tenancy(self) -> Optional[builtins.str]:
        """
        是否在专有宿主机上创建实例，取值：Default（默认）：创建普通云服务器实例。Host：创建专有宿主机实例。若您不指定DedicatedHostId，则由系统自动选择专有宿主机放置实例
        """
        return pulumi.get(self, "tenancy")


@pulumi.output_type
class InstancePrimaryNetworkInterface(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "securityGroupIds":
            suggest = "security_group_ids"
        elif key == "subnetId":
            suggest = "subnet_id"
        elif key == "ipv6AddressCount":
            suggest = "ipv6_address_count"
        elif key == "ipv6Addresses":
            suggest = "ipv6_addresses"
        elif key == "macAddress":
            suggest = "mac_address"
        elif key == "networkInterfaceId":
            suggest = "network_interface_id"
        elif key == "primaryIpAddress":
            suggest = "primary_ip_address"
        elif key == "privateIpAddresses":
            suggest = "private_ip_addresses"
        elif key == "vpcId":
            suggest = "vpc_id"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in InstancePrimaryNetworkInterface. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        InstancePrimaryNetworkInterface.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        InstancePrimaryNetworkInterface.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 security_group_ids: Sequence[builtins.str],
                 subnet_id: builtins.str,
                 ipv6_address_count: Optional[builtins.int] = None,
                 ipv6_addresses: Optional[Sequence[builtins.str]] = None,
                 mac_address: Optional[builtins.str] = None,
                 network_interface_id: Optional[builtins.str] = None,
                 primary_ip_address: Optional[builtins.str] = None,
                 private_ip_addresses: Optional[Sequence[builtins.str]] = None,
                 vpc_id: Optional[builtins.str] = None):
        """
        :param Sequence[builtins.str] security_group_ids: 实例的安全组ID。
        :param builtins.str subnet_id: 实例的子网ID。
        :param builtins.int ipv6_address_count: 实例的IPv6地址数量。
        :param Sequence[builtins.str] ipv6_addresses: 实例的IPv6地址。
        :param builtins.str mac_address: 实例的MAC地址。
        :param builtins.str network_interface_id: 实例的网络接口ID。
        :param builtins.str primary_ip_address: 实例的主IP地址。
        :param Sequence[builtins.str] private_ip_addresses: 实例的私有IP地址。
        :param builtins.str vpc_id: 实例的VPC ID。
        """
        pulumi.set(__self__, "security_group_ids", security_group_ids)
        pulumi.set(__self__, "subnet_id", subnet_id)
        if ipv6_address_count is not None:
            pulumi.set(__self__, "ipv6_address_count", ipv6_address_count)
        if ipv6_addresses is not None:
            pulumi.set(__self__, "ipv6_addresses", ipv6_addresses)
        if mac_address is not None:
            pulumi.set(__self__, "mac_address", mac_address)
        if network_interface_id is not None:
            pulumi.set(__self__, "network_interface_id", network_interface_id)
        if primary_ip_address is not None:
            pulumi.set(__self__, "primary_ip_address", primary_ip_address)
        if private_ip_addresses is not None:
            pulumi.set(__self__, "private_ip_addresses", private_ip_addresses)
        if vpc_id is not None:
            pulumi.set(__self__, "vpc_id", vpc_id)

    @property
    @pulumi.getter(name="securityGroupIds")
    def security_group_ids(self) -> Sequence[builtins.str]:
        """
        实例的安全组ID。
        """
        return pulumi.get(self, "security_group_ids")

    @property
    @pulumi.getter(name="subnetId")
    def subnet_id(self) -> builtins.str:
        """
        实例的子网ID。
        """
        return pulumi.get(self, "subnet_id")

    @property
    @pulumi.getter(name="ipv6AddressCount")
    def ipv6_address_count(self) -> Optional[builtins.int]:
        """
        实例的IPv6地址数量。
        """
        return pulumi.get(self, "ipv6_address_count")

    @property
    @pulumi.getter(name="ipv6Addresses")
    def ipv6_addresses(self) -> Optional[Sequence[builtins.str]]:
        """
        实例的IPv6地址。
        """
        return pulumi.get(self, "ipv6_addresses")

    @property
    @pulumi.getter(name="macAddress")
    def mac_address(self) -> Optional[builtins.str]:
        """
        实例的MAC地址。
        """
        return pulumi.get(self, "mac_address")

    @property
    @pulumi.getter(name="networkInterfaceId")
    def network_interface_id(self) -> Optional[builtins.str]:
        """
        实例的网络接口ID。
        """
        return pulumi.get(self, "network_interface_id")

    @property
    @pulumi.getter(name="primaryIpAddress")
    def primary_ip_address(self) -> Optional[builtins.str]:
        """
        实例的主IP地址。
        """
        return pulumi.get(self, "primary_ip_address")

    @property
    @pulumi.getter(name="privateIpAddresses")
    def private_ip_addresses(self) -> Optional[Sequence[builtins.str]]:
        """
        实例的私有IP地址。
        """
        return pulumi.get(self, "private_ip_addresses")

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> Optional[builtins.str]:
        """
        实例的VPC ID。
        """
        return pulumi.get(self, "vpc_id")


@pulumi.output_type
class InstanceSecondaryNetworkInterface(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "ipv6AddressCount":
            suggest = "ipv6_address_count"
        elif key == "primaryIpAddress":
            suggest = "primary_ip_address"
        elif key == "privateIpAddresses":
            suggest = "private_ip_addresses"
        elif key == "securityGroupIds":
            suggest = "security_group_ids"
        elif key == "subnetId":
            suggest = "subnet_id"
        elif key == "vpcId":
            suggest = "vpc_id"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in InstanceSecondaryNetworkInterface. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        InstanceSecondaryNetworkInterface.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        InstanceSecondaryNetworkInterface.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 ipv6_address_count: Optional[builtins.int] = None,
                 primary_ip_address: Optional[builtins.str] = None,
                 private_ip_addresses: Optional[Sequence[builtins.str]] = None,
                 security_group_ids: Optional[Sequence[builtins.str]] = None,
                 subnet_id: Optional[builtins.str] = None,
                 vpc_id: Optional[builtins.str] = None):
        """
        :param builtins.int ipv6_address_count: 实例的IPv6地址数量。
        :param builtins.str primary_ip_address: 实例的主IP地址。
        :param Sequence[builtins.str] private_ip_addresses: 实例的私有IP地址。
        :param Sequence[builtins.str] security_group_ids: 实例的安全组ID。
        :param builtins.str subnet_id: 实例的子网ID。
        :param builtins.str vpc_id: 实例的VPC ID。
        """
        if ipv6_address_count is not None:
            pulumi.set(__self__, "ipv6_address_count", ipv6_address_count)
        if primary_ip_address is not None:
            pulumi.set(__self__, "primary_ip_address", primary_ip_address)
        if private_ip_addresses is not None:
            pulumi.set(__self__, "private_ip_addresses", private_ip_addresses)
        if security_group_ids is not None:
            pulumi.set(__self__, "security_group_ids", security_group_ids)
        if subnet_id is not None:
            pulumi.set(__self__, "subnet_id", subnet_id)
        if vpc_id is not None:
            pulumi.set(__self__, "vpc_id", vpc_id)

    @property
    @pulumi.getter(name="ipv6AddressCount")
    def ipv6_address_count(self) -> Optional[builtins.int]:
        """
        实例的IPv6地址数量。
        """
        return pulumi.get(self, "ipv6_address_count")

    @property
    @pulumi.getter(name="primaryIpAddress")
    def primary_ip_address(self) -> Optional[builtins.str]:
        """
        实例的主IP地址。
        """
        return pulumi.get(self, "primary_ip_address")

    @property
    @pulumi.getter(name="privateIpAddresses")
    def private_ip_addresses(self) -> Optional[Sequence[builtins.str]]:
        """
        实例的私有IP地址。
        """
        return pulumi.get(self, "private_ip_addresses")

    @property
    @pulumi.getter(name="securityGroupIds")
    def security_group_ids(self) -> Optional[Sequence[builtins.str]]:
        """
        实例的安全组ID。
        """
        return pulumi.get(self, "security_group_ids")

    @property
    @pulumi.getter(name="subnetId")
    def subnet_id(self) -> Optional[builtins.str]:
        """
        实例的子网ID。
        """
        return pulumi.get(self, "subnet_id")

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> Optional[builtins.str]:
        """
        实例的VPC ID。
        """
        return pulumi.get(self, "vpc_id")


@pulumi.output_type
class InstanceSystemVolume(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "deleteWithInstance":
            suggest = "delete_with_instance"
        elif key == "extraPerformanceIops":
            suggest = "extra_performance_iops"
        elif key == "extraPerformanceThroughputMb":
            suggest = "extra_performance_throughput_mb"
        elif key == "extraPerformanceTypeId":
            suggest = "extra_performance_type_id"
        elif key == "snapshotId":
            suggest = "snapshot_id"
        elif key == "volumeId":
            suggest = "volume_id"
        elif key == "volumeType":
            suggest = "volume_type"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in InstanceSystemVolume. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        InstanceSystemVolume.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        InstanceSystemVolume.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 delete_with_instance: Optional[builtins.bool] = None,
                 extra_performance_iops: Optional[builtins.int] = None,
                 extra_performance_throughput_mb: Optional[builtins.int] = None,
                 extra_performance_type_id: Optional[builtins.str] = None,
                 size: Optional[builtins.int] = None,
                 snapshot_id: Optional[builtins.str] = None,
                 volume_id: Optional[builtins.str] = None,
                 volume_type: Optional[builtins.str] = None):
        """
        :param builtins.bool delete_with_instance: 实例是否随实例删除。
        :param builtins.int extra_performance_iops: 实例的额外性能IOPS。
        :param builtins.int extra_performance_throughput_mb: 实例的额外性能吞吐量，单位MB。
        :param builtins.str extra_performance_type_id: 额外性能的类型，取值如下：Balance：均衡型额外性能。IOPS：IOPS型额外性能。Throughput：吞吐量型额外性能。
        :param builtins.int size: 实例的大小，单位GiB。
        :param builtins.str snapshot_id: 实例的快照ID。
        :param builtins.str volume_id: 实例的卷ID。
        :param builtins.str volume_type: 云盘类型，取值说明如下：PTSSD：性能型SSD。ESSD_PL0：极速型SSD云盘，PL0规格。ESSD_FlexPL: 极速型SSD云盘，FlexPL规格。TSSD_TL0：吞吐型SSD云盘。
        """
        if delete_with_instance is not None:
            pulumi.set(__self__, "delete_with_instance", delete_with_instance)
        if extra_performance_iops is not None:
            pulumi.set(__self__, "extra_performance_iops", extra_performance_iops)
        if extra_performance_throughput_mb is not None:
            pulumi.set(__self__, "extra_performance_throughput_mb", extra_performance_throughput_mb)
        if extra_performance_type_id is not None:
            pulumi.set(__self__, "extra_performance_type_id", extra_performance_type_id)
        if size is not None:
            pulumi.set(__self__, "size", size)
        if snapshot_id is not None:
            pulumi.set(__self__, "snapshot_id", snapshot_id)
        if volume_id is not None:
            pulumi.set(__self__, "volume_id", volume_id)
        if volume_type is not None:
            pulumi.set(__self__, "volume_type", volume_type)

    @property
    @pulumi.getter(name="deleteWithInstance")
    def delete_with_instance(self) -> Optional[builtins.bool]:
        """
        实例是否随实例删除。
        """
        return pulumi.get(self, "delete_with_instance")

    @property
    @pulumi.getter(name="extraPerformanceIops")
    def extra_performance_iops(self) -> Optional[builtins.int]:
        """
        实例的额外性能IOPS。
        """
        return pulumi.get(self, "extra_performance_iops")

    @property
    @pulumi.getter(name="extraPerformanceThroughputMb")
    def extra_performance_throughput_mb(self) -> Optional[builtins.int]:
        """
        实例的额外性能吞吐量，单位MB。
        """
        return pulumi.get(self, "extra_performance_throughput_mb")

    @property
    @pulumi.getter(name="extraPerformanceTypeId")
    def extra_performance_type_id(self) -> Optional[builtins.str]:
        """
        额外性能的类型，取值如下：Balance：均衡型额外性能。IOPS：IOPS型额外性能。Throughput：吞吐量型额外性能。
        """
        return pulumi.get(self, "extra_performance_type_id")

    @property
    @pulumi.getter
    def size(self) -> Optional[builtins.int]:
        """
        实例的大小，单位GiB。
        """
        return pulumi.get(self, "size")

    @property
    @pulumi.getter(name="snapshotId")
    def snapshot_id(self) -> Optional[builtins.str]:
        """
        实例的快照ID。
        """
        return pulumi.get(self, "snapshot_id")

    @property
    @pulumi.getter(name="volumeId")
    def volume_id(self) -> Optional[builtins.str]:
        """
        实例的卷ID。
        """
        return pulumi.get(self, "volume_id")

    @property
    @pulumi.getter(name="volumeType")
    def volume_type(self) -> Optional[builtins.str]:
        """
        云盘类型，取值说明如下：PTSSD：性能型SSD。ESSD_PL0：极速型SSD云盘，PL0规格。ESSD_FlexPL: 极速型SSD云盘，FlexPL规格。TSSD_TL0：吞吐型SSD云盘。
        """
        return pulumi.get(self, "volume_type")


@pulumi.output_type
class InstanceTag(dict):
    def __init__(__self__, *,
                 key: Optional[builtins.str] = None,
                 value: Optional[builtins.str] = None):
        """
        :param builtins.str key: 实例的键。
        :param builtins.str value: 实例的值。
        """
        if key is not None:
            pulumi.set(__self__, "key", key)
        if value is not None:
            pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> Optional[builtins.str]:
        """
        实例的键。
        """
        return pulumi.get(self, "key")

    @property
    @pulumi.getter
    def value(self) -> Optional[builtins.str]:
        """
        实例的值。
        """
        return pulumi.get(self, "value")


@pulumi.output_type
class GetImageDetectionResultsResult(dict):
    def __init__(__self__, *,
                 detection_status: builtins.str,
                 items: Sequence['outputs.GetImageDetectionResultsItemResult']):
        """
        :param builtins.str detection_status: 检测状态。可以选择Finished（已完成）、Processing（处理中）类型。
        :param Sequence['GetImageDetectionResultsItemArgs'] items: 镜像检测项详情。
        """
        pulumi.set(__self__, "detection_status", detection_status)
        pulumi.set(__self__, "items", items)

    @property
    @pulumi.getter(name="detectionStatus")
    def detection_status(self) -> builtins.str:
        """
        检测状态。可以选择Finished（已完成）、Processing（处理中）类型。
        """
        return pulumi.get(self, "detection_status")

    @property
    @pulumi.getter
    def items(self) -> Sequence['outputs.GetImageDetectionResultsItemResult']:
        """
        镜像检测项详情。
        """
        return pulumi.get(self, "items")


@pulumi.output_type
class GetImageDetectionResultsItemResult(dict):
    def __init__(__self__, *,
                 name: builtins.str,
                 result: builtins.str,
                 risk_code: builtins.str,
                 risk_level: builtins.str):
        """
        :param builtins.str name: 检测项名称。
        :param builtins.str result: 该检测项对应结果。
        :param builtins.str risk_code: 风险描述码。
        :param builtins.str risk_level: 风险等级。若该参数返回值为空，表示无风险。
        """
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "result", result)
        pulumi.set(__self__, "risk_code", risk_code)
        pulumi.set(__self__, "risk_level", risk_level)

    @property
    @pulumi.getter
    def name(self) -> builtins.str:
        """
        检测项名称。
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def result(self) -> builtins.str:
        """
        该检测项对应结果。
        """
        return pulumi.get(self, "result")

    @property
    @pulumi.getter(name="riskCode")
    def risk_code(self) -> builtins.str:
        """
        风险描述码。
        """
        return pulumi.get(self, "risk_code")

    @property
    @pulumi.getter(name="riskLevel")
    def risk_level(self) -> builtins.str:
        """
        风险等级。若该参数返回值为空，表示无风险。
        """
        return pulumi.get(self, "risk_level")


@pulumi.output_type
class GetImageSnapshotResult(dict):
    def __init__(__self__, *,
                 size: builtins.int,
                 snapshot_id: builtins.str,
                 volume_kind: builtins.str):
        """
        :param builtins.int size: 快照大小。单位为GiB。
        :param builtins.str snapshot_id: 快照ID。
        :param builtins.str volume_kind: 云盘种类。system：系统盘。data：数据盘。
        """
        pulumi.set(__self__, "size", size)
        pulumi.set(__self__, "snapshot_id", snapshot_id)
        pulumi.set(__self__, "volume_kind", volume_kind)

    @property
    @pulumi.getter
    def size(self) -> builtins.int:
        """
        快照大小。单位为GiB。
        """
        return pulumi.get(self, "size")

    @property
    @pulumi.getter(name="snapshotId")
    def snapshot_id(self) -> builtins.str:
        """
        快照ID。
        """
        return pulumi.get(self, "snapshot_id")

    @property
    @pulumi.getter(name="volumeKind")
    def volume_kind(self) -> builtins.str:
        """
        云盘种类。system：系统盘。data：数据盘。
        """
        return pulumi.get(self, "volume_kind")


@pulumi.output_type
class GetImageTagResult(dict):
    def __init__(__self__, *,
                 key: builtins.str,
                 value: builtins.str):
        """
        :param builtins.str key: 镜像标签的标签键。
        :param builtins.str value: 镜像标签的值。
        """
        pulumi.set(__self__, "key", key)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> builtins.str:
        """
        镜像标签的标签键。
        """
        return pulumi.get(self, "key")

    @property
    @pulumi.getter
    def value(self) -> builtins.str:
        """
        镜像标签的值。
        """
        return pulumi.get(self, "value")


@pulumi.output_type
class GetInstanceCpuMemoryResult(dict):
    def __init__(__self__, *,
                 core_count: builtins.int,
                 cpu_number: builtins.int,
                 memory_size: builtins.int,
                 threads_per_core: builtins.int):
        """
        :param builtins.int core_count: 实例的核数。
        :param builtins.int cpu_number: 实例的CPU数量。
        :param builtins.int memory_size: 实例的内存大小，单位MB。
        :param builtins.int threads_per_core: 实例的每核线程数。
        """
        pulumi.set(__self__, "core_count", core_count)
        pulumi.set(__self__, "cpu_number", cpu_number)
        pulumi.set(__self__, "memory_size", memory_size)
        pulumi.set(__self__, "threads_per_core", threads_per_core)

    @property
    @pulumi.getter(name="coreCount")
    def core_count(self) -> builtins.int:
        """
        实例的核数。
        """
        return pulumi.get(self, "core_count")

    @property
    @pulumi.getter(name="cpuNumber")
    def cpu_number(self) -> builtins.int:
        """
        实例的CPU数量。
        """
        return pulumi.get(self, "cpu_number")

    @property
    @pulumi.getter(name="memorySize")
    def memory_size(self) -> builtins.int:
        """
        实例的内存大小，单位MB。
        """
        return pulumi.get(self, "memory_size")

    @property
    @pulumi.getter(name="threadsPerCore")
    def threads_per_core(self) -> builtins.int:
        """
        实例的每核线程数。
        """
        return pulumi.get(self, "threads_per_core")


@pulumi.output_type
class GetInstanceEipAddressResult(dict):
    def __init__(__self__, *,
                 allocation_id: builtins.str,
                 bandwidth_mbps: builtins.int,
                 bandwidth_package_id: builtins.str,
                 charge_type: builtins.str,
                 ip_address: builtins.str,
                 isp: builtins.str,
                 release_with_instance: builtins.bool):
        """
        :param builtins.str allocation_id: 实例的分配ID。
        :param builtins.int bandwidth_mbps: 公网IP的带宽上限，默认值为1，单位：Mbps。
                   - `ChargeType`传入`PayByBandwidth`：取值范围1～500。
                   - `ChargeType`传入`PayByTraffic`：取值范围1～200。
        :param builtins.str bandwidth_package_id: 共享带宽包的ID，表示将公网IP加入到共享带宽包。
                   - 您可以调用[DescribeBandwidthPackages](https://www.volcengine.com/docs/6623/100685)接口，查询共享带宽包的ID。
                   - 公网IP加入到共享带宽包必须同时满足如下条件：
                     - 二者的安全防护类型相同。
                     - 二者的地域相同。
                     - 公网IP的计费方式必须是按量计费。
                     - 共享带宽包为IPv4类型。
        :param builtins.str charge_type: 公网IP的计费方式，取值：
                   - PayByBandwidth（默认）：按量计费-按带宽上限计费。
                   - PayByTraffic：按量计费-按实际流量计费。
                   - PrePaid：包年包月。
                 
                 **提示:**
                 实例的计费类型`InstanceChargeType`取值为`PostPaid`时，该参数取值不能为`PrePaid`。
        :param builtins.str ip_address: 实例的IP地址。
        :param builtins.str isp: 公网IP的线路类型，默认为BGP。取值：
                   - BGP：BGP（多线）。
                   - 若您的账号已申请并开通了静态单线权限，则可传入如下取值：
                     - ChinaMobile：中国移动静态单线。
                     - ChinaTelecom：中国电信静态单线。
                     - ChinaUnicom：中国联通静态单线。
                   - 若您的账号已申请并开通了BGP单线权限，则可传入SingleLine_BGP。
                   - 若您的账号已申请并开通了静态BGP权限，则可传入Static_BGP。
        :param builtins.bool release_with_instance: 实例是否随实例释放。
        """
        pulumi.set(__self__, "allocation_id", allocation_id)
        pulumi.set(__self__, "bandwidth_mbps", bandwidth_mbps)
        pulumi.set(__self__, "bandwidth_package_id", bandwidth_package_id)
        pulumi.set(__self__, "charge_type", charge_type)
        pulumi.set(__self__, "ip_address", ip_address)
        pulumi.set(__self__, "isp", isp)
        pulumi.set(__self__, "release_with_instance", release_with_instance)

    @property
    @pulumi.getter(name="allocationId")
    def allocation_id(self) -> builtins.str:
        """
        实例的分配ID。
        """
        return pulumi.get(self, "allocation_id")

    @property
    @pulumi.getter(name="bandwidthMbps")
    def bandwidth_mbps(self) -> builtins.int:
        """
        公网IP的带宽上限，默认值为1，单位：Mbps。
            - `ChargeType`传入`PayByBandwidth`：取值范围1～500。
            - `ChargeType`传入`PayByTraffic`：取值范围1～200。
        """
        return pulumi.get(self, "bandwidth_mbps")

    @property
    @pulumi.getter(name="bandwidthPackageId")
    def bandwidth_package_id(self) -> builtins.str:
        """
        共享带宽包的ID，表示将公网IP加入到共享带宽包。
            - 您可以调用[DescribeBandwidthPackages](https://www.volcengine.com/docs/6623/100685)接口，查询共享带宽包的ID。
            - 公网IP加入到共享带宽包必须同时满足如下条件：
              - 二者的安全防护类型相同。
              - 二者的地域相同。
              - 公网IP的计费方式必须是按量计费。
              - 共享带宽包为IPv4类型。
        """
        return pulumi.get(self, "bandwidth_package_id")

    @property
    @pulumi.getter(name="chargeType")
    def charge_type(self) -> builtins.str:
        """
        公网IP的计费方式，取值：
            - PayByBandwidth（默认）：按量计费-按带宽上限计费。
            - PayByTraffic：按量计费-按实际流量计费。
            - PrePaid：包年包月。
          
          **提示:**
          实例的计费类型`InstanceChargeType`取值为`PostPaid`时，该参数取值不能为`PrePaid`。
        """
        return pulumi.get(self, "charge_type")

    @property
    @pulumi.getter(name="ipAddress")
    def ip_address(self) -> builtins.str:
        """
        实例的IP地址。
        """
        return pulumi.get(self, "ip_address")

    @property
    @pulumi.getter
    def isp(self) -> builtins.str:
        """
        公网IP的线路类型，默认为BGP。取值：
            - BGP：BGP（多线）。
            - 若您的账号已申请并开通了静态单线权限，则可传入如下取值：
              - ChinaMobile：中国移动静态单线。
              - ChinaTelecom：中国电信静态单线。
              - ChinaUnicom：中国联通静态单线。
            - 若您的账号已申请并开通了BGP单线权限，则可传入SingleLine_BGP。
            - 若您的账号已申请并开通了静态BGP权限，则可传入Static_BGP。
        """
        return pulumi.get(self, "isp")

    @property
    @pulumi.getter(name="releaseWithInstance")
    def release_with_instance(self) -> builtins.bool:
        """
        实例是否随实例释放。
        """
        return pulumi.get(self, "release_with_instance")


@pulumi.output_type
class GetInstanceImageResult(dict):
    def __init__(__self__, *,
                 image_id: builtins.str,
                 image_release_version: builtins.str,
                 keep_image_credential: builtins.bool,
                 security_enhancement_strategy: builtins.str):
        """
        :param builtins.str image_id: 实例的镜像ID。
        :param builtins.str image_release_version: 实例的镜像发布版本。
        :param builtins.bool keep_image_credential: 实例是否保留镜像凭证。
        :param builtins.str security_enhancement_strategy: 实例的安全增强策略。Active：开启安全加固，仅对公共镜像生效。InActive：关闭安全加固，对所有镜像生效。
        """
        pulumi.set(__self__, "image_id", image_id)
        pulumi.set(__self__, "image_release_version", image_release_version)
        pulumi.set(__self__, "keep_image_credential", keep_image_credential)
        pulumi.set(__self__, "security_enhancement_strategy", security_enhancement_strategy)

    @property
    @pulumi.getter(name="imageId")
    def image_id(self) -> builtins.str:
        """
        实例的镜像ID。
        """
        return pulumi.get(self, "image_id")

    @property
    @pulumi.getter(name="imageReleaseVersion")
    def image_release_version(self) -> builtins.str:
        """
        实例的镜像发布版本。
        """
        return pulumi.get(self, "image_release_version")

    @property
    @pulumi.getter(name="keepImageCredential")
    def keep_image_credential(self) -> builtins.bool:
        """
        实例是否保留镜像凭证。
        """
        return pulumi.get(self, "keep_image_credential")

    @property
    @pulumi.getter(name="securityEnhancementStrategy")
    def security_enhancement_strategy(self) -> builtins.str:
        """
        实例的安全增强策略。Active：开启安全加固，仅对公共镜像生效。InActive：关闭安全加固，对所有镜像生效。
        """
        return pulumi.get(self, "security_enhancement_strategy")


@pulumi.output_type
class GetInstanceKeyPairResult(dict):
    def __init__(__self__, *,
                 key_pair_id: builtins.str,
                 key_pair_name: builtins.str):
        """
        :param builtins.str key_pair_id: 实例的公钥。
        :param builtins.str key_pair_name: 实例的密钥对名称。
        """
        pulumi.set(__self__, "key_pair_id", key_pair_id)
        pulumi.set(__self__, "key_pair_name", key_pair_name)

    @property
    @pulumi.getter(name="keyPairId")
    def key_pair_id(self) -> builtins.str:
        """
        实例的公钥。
        """
        return pulumi.get(self, "key_pair_id")

    @property
    @pulumi.getter(name="keyPairName")
    def key_pair_name(self) -> builtins.str:
        """
        实例的密钥对名称。
        """
        return pulumi.get(self, "key_pair_name")


@pulumi.output_type
class GetInstanceOperationSystemResult(dict):
    def __init__(__self__, *,
                 name: builtins.str,
                 type: builtins.str):
        """
        :param builtins.str name: 实例的操作系统名称。
        :param builtins.str type: 实例的操作系统类型。Linux：Linux系统。Windows：Windows系统。
        """
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter
    def name(self) -> builtins.str:
        """
        实例的操作系统名称。
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def type(self) -> builtins.str:
        """
        实例的操作系统类型。Linux：Linux系统。Windows：Windows系统。
        """
        return pulumi.get(self, "type")


@pulumi.output_type
class GetInstancePlacementResult(dict):
    def __init__(__self__, *,
                 affinity: builtins.str,
                 dedicated_host_cluster_id: builtins.str,
                 dedicated_host_id: builtins.str,
                 tenancy: builtins.str):
        """
        :param builtins.str affinity: 针对节省停机模式的ECS实例，停止后会释放部分资源，本参数用于查看ECS实例重新启动时是否仍固定部署在原宿主机上。取值：Host：启用节省停机模式的实例重新启动时，仍会部署在原宿主机上。Default（默认）：启用节省停机模式的实例重新启动时，会优先迁移到支持自动部署的宿主机；若支持自动部署的宿主机资源不足，则在原宿主机上进行启动。
        :param builtins.str dedicated_host_cluster_id: 实例的专用主机集群ID。
        :param builtins.str dedicated_host_id: 实例的专用主机ID。
        :param builtins.str tenancy: 是否在专有宿主机上创建实例，取值：Default（默认）：创建普通云服务器实例。Host：创建专有宿主机实例。若您不指定DedicatedHostId，则由系统自动选择专有宿主机放置实例
        """
        pulumi.set(__self__, "affinity", affinity)
        pulumi.set(__self__, "dedicated_host_cluster_id", dedicated_host_cluster_id)
        pulumi.set(__self__, "dedicated_host_id", dedicated_host_id)
        pulumi.set(__self__, "tenancy", tenancy)

    @property
    @pulumi.getter
    def affinity(self) -> builtins.str:
        """
        针对节省停机模式的ECS实例，停止后会释放部分资源，本参数用于查看ECS实例重新启动时是否仍固定部署在原宿主机上。取值：Host：启用节省停机模式的实例重新启动时，仍会部署在原宿主机上。Default（默认）：启用节省停机模式的实例重新启动时，会优先迁移到支持自动部署的宿主机；若支持自动部署的宿主机资源不足，则在原宿主机上进行启动。
        """
        return pulumi.get(self, "affinity")

    @property
    @pulumi.getter(name="dedicatedHostClusterId")
    def dedicated_host_cluster_id(self) -> builtins.str:
        """
        实例的专用主机集群ID。
        """
        return pulumi.get(self, "dedicated_host_cluster_id")

    @property
    @pulumi.getter(name="dedicatedHostId")
    def dedicated_host_id(self) -> builtins.str:
        """
        实例的专用主机ID。
        """
        return pulumi.get(self, "dedicated_host_id")

    @property
    @pulumi.getter
    def tenancy(self) -> builtins.str:
        """
        是否在专有宿主机上创建实例，取值：Default（默认）：创建普通云服务器实例。Host：创建专有宿主机实例。若您不指定DedicatedHostId，则由系统自动选择专有宿主机放置实例
        """
        return pulumi.get(self, "tenancy")


@pulumi.output_type
class GetInstancePrimaryNetworkInterfaceResult(dict):
    def __init__(__self__, *,
                 ipv6_address_count: builtins.int,
                 ipv6_addresses: Sequence[builtins.str],
                 mac_address: builtins.str,
                 network_interface_id: builtins.str,
                 primary_ip_address: builtins.str,
                 private_ip_addresses: Sequence[builtins.str],
                 security_group_ids: Sequence[builtins.str],
                 subnet_id: builtins.str,
                 vpc_id: builtins.str):
        """
        :param builtins.int ipv6_address_count: 实例的IPv6地址数量。
        :param Sequence[builtins.str] ipv6_addresses: 实例的IPv6地址。
        :param builtins.str mac_address: 实例的MAC地址。
        :param builtins.str network_interface_id: 实例的网络接口ID。
        :param builtins.str primary_ip_address: 实例的主IP地址。
        :param Sequence[builtins.str] private_ip_addresses: 实例的私有IP地址。
        :param Sequence[builtins.str] security_group_ids: 实例的安全组ID。
        :param builtins.str subnet_id: 实例的子网ID。
        :param builtins.str vpc_id: 实例的VPC ID。
        """
        pulumi.set(__self__, "ipv6_address_count", ipv6_address_count)
        pulumi.set(__self__, "ipv6_addresses", ipv6_addresses)
        pulumi.set(__self__, "mac_address", mac_address)
        pulumi.set(__self__, "network_interface_id", network_interface_id)
        pulumi.set(__self__, "primary_ip_address", primary_ip_address)
        pulumi.set(__self__, "private_ip_addresses", private_ip_addresses)
        pulumi.set(__self__, "security_group_ids", security_group_ids)
        pulumi.set(__self__, "subnet_id", subnet_id)
        pulumi.set(__self__, "vpc_id", vpc_id)

    @property
    @pulumi.getter(name="ipv6AddressCount")
    def ipv6_address_count(self) -> builtins.int:
        """
        实例的IPv6地址数量。
        """
        return pulumi.get(self, "ipv6_address_count")

    @property
    @pulumi.getter(name="ipv6Addresses")
    def ipv6_addresses(self) -> Sequence[builtins.str]:
        """
        实例的IPv6地址。
        """
        return pulumi.get(self, "ipv6_addresses")

    @property
    @pulumi.getter(name="macAddress")
    def mac_address(self) -> builtins.str:
        """
        实例的MAC地址。
        """
        return pulumi.get(self, "mac_address")

    @property
    @pulumi.getter(name="networkInterfaceId")
    def network_interface_id(self) -> builtins.str:
        """
        实例的网络接口ID。
        """
        return pulumi.get(self, "network_interface_id")

    @property
    @pulumi.getter(name="primaryIpAddress")
    def primary_ip_address(self) -> builtins.str:
        """
        实例的主IP地址。
        """
        return pulumi.get(self, "primary_ip_address")

    @property
    @pulumi.getter(name="privateIpAddresses")
    def private_ip_addresses(self) -> Sequence[builtins.str]:
        """
        实例的私有IP地址。
        """
        return pulumi.get(self, "private_ip_addresses")

    @property
    @pulumi.getter(name="securityGroupIds")
    def security_group_ids(self) -> Sequence[builtins.str]:
        """
        实例的安全组ID。
        """
        return pulumi.get(self, "security_group_ids")

    @property
    @pulumi.getter(name="subnetId")
    def subnet_id(self) -> builtins.str:
        """
        实例的子网ID。
        """
        return pulumi.get(self, "subnet_id")

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> builtins.str:
        """
        实例的VPC ID。
        """
        return pulumi.get(self, "vpc_id")


@pulumi.output_type
class GetInstanceSecondaryNetworkInterfaceResult(dict):
    def __init__(__self__, *,
                 ipv6_address_count: builtins.int,
                 ipv6_addresses: Sequence[builtins.str],
                 mac_address: builtins.str,
                 network_interface_id: builtins.str,
                 primary_ip_address: builtins.str,
                 private_ip_addresses: Sequence[builtins.str],
                 security_group_ids: Sequence[builtins.str],
                 subnet_id: builtins.str,
                 vpc_id: builtins.str):
        """
        :param builtins.int ipv6_address_count: 实例的IPv6地址数量。
        :param Sequence[builtins.str] ipv6_addresses: 实例的IPv6地址。
        :param builtins.str mac_address: 实例的MAC地址。
        :param builtins.str network_interface_id: 实例的网络接口ID。
        :param builtins.str primary_ip_address: 实例的主IP地址。
        :param Sequence[builtins.str] private_ip_addresses: 实例的私有IP地址。
        :param Sequence[builtins.str] security_group_ids: 实例的安全组ID。
        :param builtins.str subnet_id: 实例的子网ID。
        :param builtins.str vpc_id: 实例的VPC ID。
        """
        pulumi.set(__self__, "ipv6_address_count", ipv6_address_count)
        pulumi.set(__self__, "ipv6_addresses", ipv6_addresses)
        pulumi.set(__self__, "mac_address", mac_address)
        pulumi.set(__self__, "network_interface_id", network_interface_id)
        pulumi.set(__self__, "primary_ip_address", primary_ip_address)
        pulumi.set(__self__, "private_ip_addresses", private_ip_addresses)
        pulumi.set(__self__, "security_group_ids", security_group_ids)
        pulumi.set(__self__, "subnet_id", subnet_id)
        pulumi.set(__self__, "vpc_id", vpc_id)

    @property
    @pulumi.getter(name="ipv6AddressCount")
    def ipv6_address_count(self) -> builtins.int:
        """
        实例的IPv6地址数量。
        """
        return pulumi.get(self, "ipv6_address_count")

    @property
    @pulumi.getter(name="ipv6Addresses")
    def ipv6_addresses(self) -> Sequence[builtins.str]:
        """
        实例的IPv6地址。
        """
        return pulumi.get(self, "ipv6_addresses")

    @property
    @pulumi.getter(name="macAddress")
    def mac_address(self) -> builtins.str:
        """
        实例的MAC地址。
        """
        return pulumi.get(self, "mac_address")

    @property
    @pulumi.getter(name="networkInterfaceId")
    def network_interface_id(self) -> builtins.str:
        """
        实例的网络接口ID。
        """
        return pulumi.get(self, "network_interface_id")

    @property
    @pulumi.getter(name="primaryIpAddress")
    def primary_ip_address(self) -> builtins.str:
        """
        实例的主IP地址。
        """
        return pulumi.get(self, "primary_ip_address")

    @property
    @pulumi.getter(name="privateIpAddresses")
    def private_ip_addresses(self) -> Sequence[builtins.str]:
        """
        实例的私有IP地址。
        """
        return pulumi.get(self, "private_ip_addresses")

    @property
    @pulumi.getter(name="securityGroupIds")
    def security_group_ids(self) -> Sequence[builtins.str]:
        """
        实例的安全组ID。
        """
        return pulumi.get(self, "security_group_ids")

    @property
    @pulumi.getter(name="subnetId")
    def subnet_id(self) -> builtins.str:
        """
        实例的子网ID。
        """
        return pulumi.get(self, "subnet_id")

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> builtins.str:
        """
        实例的VPC ID。
        """
        return pulumi.get(self, "vpc_id")


@pulumi.output_type
class GetInstanceSystemVolumeResult(dict):
    def __init__(__self__, *,
                 delete_with_instance: builtins.bool,
                 extra_performance_iops: builtins.int,
                 extra_performance_throughput_mb: builtins.int,
                 extra_performance_type_id: builtins.str,
                 size: builtins.int,
                 snapshot_id: builtins.str,
                 volume_id: builtins.str,
                 volume_type: builtins.str):
        """
        :param builtins.bool delete_with_instance: 实例是否随实例删除。
        :param builtins.int extra_performance_iops: 实例的额外性能IOPS。
        :param builtins.int extra_performance_throughput_mb: 实例的额外性能吞吐量，单位MB。
        :param builtins.str extra_performance_type_id: 额外性能的类型，取值如下：Balance：均衡型额外性能。IOPS：IOPS型额外性能。Throughput：吞吐量型额外性能。
        :param builtins.int size: 实例的大小，单位GiB。
        :param builtins.str snapshot_id: 实例的快照ID。
        :param builtins.str volume_id: 实例的卷ID。
        :param builtins.str volume_type: 云盘类型，取值说明如下：PTSSD：性能型SSD。ESSD_PL0：极速型SSD云盘，PL0规格。ESSD_FlexPL: 极速型SSD云盘，FlexPL规格。TSSD_TL0：吞吐型SSD云盘。
        """
        pulumi.set(__self__, "delete_with_instance", delete_with_instance)
        pulumi.set(__self__, "extra_performance_iops", extra_performance_iops)
        pulumi.set(__self__, "extra_performance_throughput_mb", extra_performance_throughput_mb)
        pulumi.set(__self__, "extra_performance_type_id", extra_performance_type_id)
        pulumi.set(__self__, "size", size)
        pulumi.set(__self__, "snapshot_id", snapshot_id)
        pulumi.set(__self__, "volume_id", volume_id)
        pulumi.set(__self__, "volume_type", volume_type)

    @property
    @pulumi.getter(name="deleteWithInstance")
    def delete_with_instance(self) -> builtins.bool:
        """
        实例是否随实例删除。
        """
        return pulumi.get(self, "delete_with_instance")

    @property
    @pulumi.getter(name="extraPerformanceIops")
    def extra_performance_iops(self) -> builtins.int:
        """
        实例的额外性能IOPS。
        """
        return pulumi.get(self, "extra_performance_iops")

    @property
    @pulumi.getter(name="extraPerformanceThroughputMb")
    def extra_performance_throughput_mb(self) -> builtins.int:
        """
        实例的额外性能吞吐量，单位MB。
        """
        return pulumi.get(self, "extra_performance_throughput_mb")

    @property
    @pulumi.getter(name="extraPerformanceTypeId")
    def extra_performance_type_id(self) -> builtins.str:
        """
        额外性能的类型，取值如下：Balance：均衡型额外性能。IOPS：IOPS型额外性能。Throughput：吞吐量型额外性能。
        """
        return pulumi.get(self, "extra_performance_type_id")

    @property
    @pulumi.getter
    def size(self) -> builtins.int:
        """
        实例的大小，单位GiB。
        """
        return pulumi.get(self, "size")

    @property
    @pulumi.getter(name="snapshotId")
    def snapshot_id(self) -> builtins.str:
        """
        实例的快照ID。
        """
        return pulumi.get(self, "snapshot_id")

    @property
    @pulumi.getter(name="volumeId")
    def volume_id(self) -> builtins.str:
        """
        实例的卷ID。
        """
        return pulumi.get(self, "volume_id")

    @property
    @pulumi.getter(name="volumeType")
    def volume_type(self) -> builtins.str:
        """
        云盘类型，取值说明如下：PTSSD：性能型SSD。ESSD_PL0：极速型SSD云盘，PL0规格。ESSD_FlexPL: 极速型SSD云盘，FlexPL规格。TSSD_TL0：吞吐型SSD云盘。
        """
        return pulumi.get(self, "volume_type")


@pulumi.output_type
class GetInstanceTagResult(dict):
    def __init__(__self__, *,
                 key: builtins.str,
                 value: builtins.str):
        """
        :param builtins.str key: 实例的键。
        :param builtins.str value: 实例的值。
        """
        pulumi.set(__self__, "key", key)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> builtins.str:
        """
        实例的键。
        """
        return pulumi.get(self, "key")

    @property
    @pulumi.getter
    def value(self) -> builtins.str:
        """
        实例的值。
        """
        return pulumi.get(self, "value")





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['InstanceArgs', 'Instance']

@pulumi.input_type
class InstanceArgs:
    def __init__(__self__, *,
                 instance_configuration: pulumi.Input['InstanceInstanceConfigurationArgs'],
                 maintenance_days: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 maintenance_time: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a Instance resource.
        :param pulumi.Input['InstanceInstanceConfigurationArgs'] instance_configuration: 实例配置详情信息。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] maintenance_days: 实例的可维护日期。
        :param pulumi.Input[builtins.str] maintenance_time: 实例的可维护时间段。
        """
        pulumi.set(__self__, "instance_configuration", instance_configuration)
        if maintenance_days is not None:
            pulumi.set(__self__, "maintenance_days", maintenance_days)
        if maintenance_time is not None:
            pulumi.set(__self__, "maintenance_time", maintenance_time)

    @property
    @pulumi.getter(name="instanceConfiguration")
    def instance_configuration(self) -> pulumi.Input['InstanceInstanceConfigurationArgs']:
        """
        实例配置详情信息。
        """
        return pulumi.get(self, "instance_configuration")

    @instance_configuration.setter
    def instance_configuration(self, value: pulumi.Input['InstanceInstanceConfigurationArgs']):
        pulumi.set(self, "instance_configuration", value)

    @property
    @pulumi.getter(name="maintenanceDays")
    def maintenance_days(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        实例的可维护日期。
        """
        return pulumi.get(self, "maintenance_days")

    @maintenance_days.setter
    def maintenance_days(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "maintenance_days", value)

    @property
    @pulumi.getter(name="maintenanceTime")
    def maintenance_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例的可维护时间段。
        """
        return pulumi.get(self, "maintenance_time")

    @maintenance_time.setter
    def maintenance_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "maintenance_time", value)


@pulumi.input_type
class _InstanceState:
    def __init__(__self__, *,
                 cerebro_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 cerebro_private_domain: Optional[pulumi.Input[builtins.str]] = None,
                 cerebro_public_domain: Optional[pulumi.Input[builtins.str]] = None,
                 charge_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 cluster_id: Optional[pulumi.Input[builtins.str]] = None,
                 create_time: Optional[pulumi.Input[builtins.str]] = None,
                 enable_es_private_domain_public: Optional[pulumi.Input[builtins.bool]] = None,
                 enable_es_private_network: Optional[pulumi.Input[builtins.bool]] = None,
                 enable_es_public_network: Optional[pulumi.Input[builtins.bool]] = None,
                 enable_kibana_private_domain_public: Optional[pulumi.Input[builtins.bool]] = None,
                 enable_kibana_private_network: Optional[pulumi.Input[builtins.bool]] = None,
                 enable_kibana_public_network: Optional[pulumi.Input[builtins.bool]] = None,
                 es_eip: Optional[pulumi.Input[builtins.str]] = None,
                 es_eip_id: Optional[pulumi.Input[builtins.str]] = None,
                 es_private_endpoint: Optional[pulumi.Input[builtins.str]] = None,
                 es_private_ip_allow_list: Optional[pulumi.Input[builtins.str]] = None,
                 es_private_ip_whitelist: Optional[pulumi.Input[builtins.str]] = None,
                 es_pub_bandwidth: Optional[pulumi.Input[builtins.int]] = None,
                 es_public_endpoint: Optional[pulumi.Input[builtins.str]] = None,
                 es_public_ip_allow_list: Optional[pulumi.Input[builtins.str]] = None,
                 es_public_ip_whitelist: Optional[pulumi.Input[builtins.str]] = None,
                 expire_date: Optional[pulumi.Input[builtins.str]] = None,
                 instance_configuration: Optional[pulumi.Input['InstanceInstanceConfigurationArgs']] = None,
                 instance_id: Optional[pulumi.Input[builtins.str]] = None,
                 kibana_config: Optional[pulumi.Input['InstanceKibanaConfigArgs']] = None,
                 kibana_eip: Optional[pulumi.Input[builtins.str]] = None,
                 kibana_eip_id: Optional[pulumi.Input[builtins.str]] = None,
                 kibana_private_domain: Optional[pulumi.Input[builtins.str]] = None,
                 kibana_private_ip_allow_list: Optional[pulumi.Input[builtins.str]] = None,
                 kibana_private_ip_whitelist: Optional[pulumi.Input[builtins.str]] = None,
                 kibana_pub_bandwidth: Optional[pulumi.Input[builtins.int]] = None,
                 kibana_public_domain: Optional[pulumi.Input[builtins.str]] = None,
                 kibana_public_ip_allow_list: Optional[pulumi.Input[builtins.str]] = None,
                 kibana_public_ip_whitelist: Optional[pulumi.Input[builtins.str]] = None,
                 main_zone_id: Optional[pulumi.Input[builtins.str]] = None,
                 maintenance_days: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 maintenance_time: Optional[pulumi.Input[builtins.str]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 sub_instance_enable: Optional[pulumi.Input[builtins.str]] = None,
                 sub_instances: Optional[pulumi.Input[Sequence[pulumi.Input['InstanceSubInstanceArgs']]]] = None,
                 support_cold_node: Optional[pulumi.Input[builtins.bool]] = None,
                 total_nodes: Optional[pulumi.Input[builtins.int]] = None,
                 transfer_info: Optional[pulumi.Input['InstanceTransferInfoArgs']] = None,
                 user_id: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering Instance resources.
        :param pulumi.Input[builtins.bool] cerebro_enabled: 是否开启 cerebro。true：开启 cerebrofalse：不开启 cerebro
        :param pulumi.Input[builtins.str] cerebro_private_domain: cerebro 私网访问地址。说明Cerebro 和 Kibana 共享域名。如果是历史实例，访问地址有可能是http(s)://kibana-***开头
        :param pulumi.Input[builtins.str] cerebro_public_domain: erebro 公网访问地址。说明Cerebro 和 Kibana 共享域名。如果是历史实例，访问地址有可能是http(s)://kibana-***开头。
        :param pulumi.Input[builtins.bool] charge_enabled: 实例是否开启了计费。取值说明如下：true：已开启计费false：未开启计费
        :param pulumi.Input[builtins.str] cluster_id: 实例所属集群的 ID。
        :param pulumi.Input[builtins.str] create_time: 实例的创建时间。
        :param pulumi.Input[builtins.bool] enable_es_private_domain_public: 实例是否开启私网地址公网解析。true：已开启私网地址公网解析false：未开启私网地址公网解析
        :param pulumi.Input[builtins.bool] enable_es_private_network: 实例是否开启了私网访问。true：默认值，开启私网访问false：未开启私网访问
        :param pulumi.Input[builtins.bool] enable_es_public_network: 实例是否开启了公网访问。true：已开启公网访问false：未开启公网访问
        :param pulumi.Input[builtins.bool] enable_kibana_private_domain_public: Kibana 是否开启私网地址公网解析。true：已开启私网地址公网解析false：未开启私网地址公网解析
        :param pulumi.Input[builtins.bool] enable_kibana_private_network: Kibana 是否开启私网访问。true：默认值，已开启私网访问 false：未开启Kibana私网访问
        :param pulumi.Input[builtins.bool] enable_kibana_public_network: Kibana 是否开启了公网访问。true：已开启公网访问 false：未开启公网访问
        :param pulumi.Input[builtins.str] es_eip: 实例所绑定的 EIP。
        :param pulumi.Input[builtins.str] es_eip_id: 实例所绑定的 EIP 的 ID。
        :param pulumi.Input[builtins.str] es_private_endpoint: 实例私网访问地址。
        :param pulumi.Input[builtins.str] es_private_ip_allow_list: 实例私网地址访问白名单。同 ESPrivateIpWhitelist
        :param pulumi.Input[builtins.str] es_private_ip_whitelist: 实例私网地址访问白名单。
        :param pulumi.Input[builtins.int] es_pub_bandwidth: ES公网带宽，单位:Mbps。
        :param pulumi.Input[builtins.str] es_public_endpoint: 实例公网访问地址。
        :param pulumi.Input[builtins.str] es_public_ip_allow_list: 实例公网地址访问白名单。同 ESPublicIpWhitelist
        :param pulumi.Input[builtins.str] es_public_ip_whitelist: 实例公网地址访问白名单。
        :param pulumi.Input[builtins.str] expire_date: 包年包月实例的付费过期时间。
        :param pulumi.Input['InstanceInstanceConfigurationArgs'] instance_configuration: 实例配置详情信息。
        :param pulumi.Input[builtins.str] instance_id: 实例 ID。
        :param pulumi.Input['InstanceKibanaConfigArgs'] kibana_config: Kibana 参数配置。
        :param pulumi.Input[builtins.str] kibana_eip: Kibana 所绑定的 EIP。
        :param pulumi.Input[builtins.str] kibana_eip_id: Kibana 所绑定的 EIP 的 ID。
        :param pulumi.Input[builtins.str] kibana_private_domain: Kibana 私网访问地址。说明如果是历史实例，访问地址有可能是http(s)://kibana-***开头。
        :param pulumi.Input[builtins.str] kibana_private_ip_allow_list: Kibana 私网白名单。只有添加到白名单中的 IP 地址才可以访问可视化工具。同 KibanaPrivateIpWhitelist
        :param pulumi.Input[builtins.str] kibana_private_ip_whitelist: Kibana 私网白名单。只有添加到白名单中的 IP 地址才可以访问可视化工具。说明Cerebro 和 Kibana 共用一套白名单。
        :param pulumi.Input[builtins.int] kibana_pub_bandwidth: Kibana公网带宽，单位: Mbps
        :param pulumi.Input[builtins.str] kibana_public_domain: Kibana 公网访问地址。说明如果是历史实例，访问地址有可能是http(s)://kibana-***开头。
        :param pulumi.Input[builtins.str] kibana_public_ip_allow_list: Kibana 公网白名单。只有添加到白名单中的 IP 地址才可以访问可视化工具。同 KibanaPublicIpWhitelist
        :param pulumi.Input[builtins.str] kibana_public_ip_whitelist: Kibana 公网白名单。只有添加到白名单中的 IP 地址才可以访问可视化工具。说明Cerebro 和 Kibana 共用一套白名单
        :param pulumi.Input[builtins.str] main_zone_id: 主可用区
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] maintenance_days: 实例的可维护日期。
        :param pulumi.Input[builtins.str] maintenance_time: 实例的可维护时间段。
        :param pulumi.Input[builtins.str] status: 实例当前状态。
        :param pulumi.Input[builtins.str] sub_instance_enable: 子实例开启情况。
        :param pulumi.Input[builtins.bool] support_cold_node: 是否支持冷节点。
        :param pulumi.Input[builtins.int] total_nodes: 实例的总节点数。
        :param pulumi.Input['InstanceTransferInfoArgs'] transfer_info: 数据迁移任务信息。
        :param pulumi.Input[builtins.str] user_id: 实例所有者的用户 ID。
        """
        if cerebro_enabled is not None:
            pulumi.set(__self__, "cerebro_enabled", cerebro_enabled)
        if cerebro_private_domain is not None:
            pulumi.set(__self__, "cerebro_private_domain", cerebro_private_domain)
        if cerebro_public_domain is not None:
            pulumi.set(__self__, "cerebro_public_domain", cerebro_public_domain)
        if charge_enabled is not None:
            pulumi.set(__self__, "charge_enabled", charge_enabled)
        if cluster_id is not None:
            pulumi.set(__self__, "cluster_id", cluster_id)
        if create_time is not None:
            pulumi.set(__self__, "create_time", create_time)
        if enable_es_private_domain_public is not None:
            pulumi.set(__self__, "enable_es_private_domain_public", enable_es_private_domain_public)
        if enable_es_private_network is not None:
            pulumi.set(__self__, "enable_es_private_network", enable_es_private_network)
        if enable_es_public_network is not None:
            pulumi.set(__self__, "enable_es_public_network", enable_es_public_network)
        if enable_kibana_private_domain_public is not None:
            pulumi.set(__self__, "enable_kibana_private_domain_public", enable_kibana_private_domain_public)
        if enable_kibana_private_network is not None:
            pulumi.set(__self__, "enable_kibana_private_network", enable_kibana_private_network)
        if enable_kibana_public_network is not None:
            pulumi.set(__self__, "enable_kibana_public_network", enable_kibana_public_network)
        if es_eip is not None:
            pulumi.set(__self__, "es_eip", es_eip)
        if es_eip_id is not None:
            pulumi.set(__self__, "es_eip_id", es_eip_id)
        if es_private_endpoint is not None:
            pulumi.set(__self__, "es_private_endpoint", es_private_endpoint)
        if es_private_ip_allow_list is not None:
            pulumi.set(__self__, "es_private_ip_allow_list", es_private_ip_allow_list)
        if es_private_ip_whitelist is not None:
            pulumi.set(__self__, "es_private_ip_whitelist", es_private_ip_whitelist)
        if es_pub_bandwidth is not None:
            pulumi.set(__self__, "es_pub_bandwidth", es_pub_bandwidth)
        if es_public_endpoint is not None:
            pulumi.set(__self__, "es_public_endpoint", es_public_endpoint)
        if es_public_ip_allow_list is not None:
            pulumi.set(__self__, "es_public_ip_allow_list", es_public_ip_allow_list)
        if es_public_ip_whitelist is not None:
            pulumi.set(__self__, "es_public_ip_whitelist", es_public_ip_whitelist)
        if expire_date is not None:
            pulumi.set(__self__, "expire_date", expire_date)
        if instance_configuration is not None:
            pulumi.set(__self__, "instance_configuration", instance_configuration)
        if instance_id is not None:
            pulumi.set(__self__, "instance_id", instance_id)
        if kibana_config is not None:
            pulumi.set(__self__, "kibana_config", kibana_config)
        if kibana_eip is not None:
            pulumi.set(__self__, "kibana_eip", kibana_eip)
        if kibana_eip_id is not None:
            pulumi.set(__self__, "kibana_eip_id", kibana_eip_id)
        if kibana_private_domain is not None:
            pulumi.set(__self__, "kibana_private_domain", kibana_private_domain)
        if kibana_private_ip_allow_list is not None:
            pulumi.set(__self__, "kibana_private_ip_allow_list", kibana_private_ip_allow_list)
        if kibana_private_ip_whitelist is not None:
            pulumi.set(__self__, "kibana_private_ip_whitelist", kibana_private_ip_whitelist)
        if kibana_pub_bandwidth is not None:
            pulumi.set(__self__, "kibana_pub_bandwidth", kibana_pub_bandwidth)
        if kibana_public_domain is not None:
            pulumi.set(__self__, "kibana_public_domain", kibana_public_domain)
        if kibana_public_ip_allow_list is not None:
            pulumi.set(__self__, "kibana_public_ip_allow_list", kibana_public_ip_allow_list)
        if kibana_public_ip_whitelist is not None:
            pulumi.set(__self__, "kibana_public_ip_whitelist", kibana_public_ip_whitelist)
        if main_zone_id is not None:
            pulumi.set(__self__, "main_zone_id", main_zone_id)
        if maintenance_days is not None:
            pulumi.set(__self__, "maintenance_days", maintenance_days)
        if maintenance_time is not None:
            pulumi.set(__self__, "maintenance_time", maintenance_time)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if sub_instance_enable is not None:
            pulumi.set(__self__, "sub_instance_enable", sub_instance_enable)
        if sub_instances is not None:
            pulumi.set(__self__, "sub_instances", sub_instances)
        if support_cold_node is not None:
            pulumi.set(__self__, "support_cold_node", support_cold_node)
        if total_nodes is not None:
            pulumi.set(__self__, "total_nodes", total_nodes)
        if transfer_info is not None:
            pulumi.set(__self__, "transfer_info", transfer_info)
        if user_id is not None:
            pulumi.set(__self__, "user_id", user_id)

    @property
    @pulumi.getter(name="cerebroEnabled")
    def cerebro_enabled(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        是否开启 cerebro。true：开启 cerebrofalse：不开启 cerebro
        """
        return pulumi.get(self, "cerebro_enabled")

    @cerebro_enabled.setter
    def cerebro_enabled(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "cerebro_enabled", value)

    @property
    @pulumi.getter(name="cerebroPrivateDomain")
    def cerebro_private_domain(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        cerebro 私网访问地址。说明Cerebro 和 Kibana 共享域名。如果是历史实例，访问地址有可能是http(s)://kibana-***开头
        """
        return pulumi.get(self, "cerebro_private_domain")

    @cerebro_private_domain.setter
    def cerebro_private_domain(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "cerebro_private_domain", value)

    @property
    @pulumi.getter(name="cerebroPublicDomain")
    def cerebro_public_domain(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        erebro 公网访问地址。说明Cerebro 和 Kibana 共享域名。如果是历史实例，访问地址有可能是http(s)://kibana-***开头。
        """
        return pulumi.get(self, "cerebro_public_domain")

    @cerebro_public_domain.setter
    def cerebro_public_domain(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "cerebro_public_domain", value)

    @property
    @pulumi.getter(name="chargeEnabled")
    def charge_enabled(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        实例是否开启了计费。取值说明如下：true：已开启计费false：未开启计费
        """
        return pulumi.get(self, "charge_enabled")

    @charge_enabled.setter
    def charge_enabled(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "charge_enabled", value)

    @property
    @pulumi.getter(name="clusterId")
    def cluster_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例所属集群的 ID。
        """
        return pulumi.get(self, "cluster_id")

    @cluster_id.setter
    def cluster_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "cluster_id", value)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例的创建时间。
        """
        return pulumi.get(self, "create_time")

    @create_time.setter
    def create_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "create_time", value)

    @property
    @pulumi.getter(name="enableEsPrivateDomainPublic")
    def enable_es_private_domain_public(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        实例是否开启私网地址公网解析。true：已开启私网地址公网解析false：未开启私网地址公网解析
        """
        return pulumi.get(self, "enable_es_private_domain_public")

    @enable_es_private_domain_public.setter
    def enable_es_private_domain_public(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "enable_es_private_domain_public", value)

    @property
    @pulumi.getter(name="enableEsPrivateNetwork")
    def enable_es_private_network(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        实例是否开启了私网访问。true：默认值，开启私网访问false：未开启私网访问
        """
        return pulumi.get(self, "enable_es_private_network")

    @enable_es_private_network.setter
    def enable_es_private_network(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "enable_es_private_network", value)

    @property
    @pulumi.getter(name="enableEsPublicNetwork")
    def enable_es_public_network(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        实例是否开启了公网访问。true：已开启公网访问false：未开启公网访问
        """
        return pulumi.get(self, "enable_es_public_network")

    @enable_es_public_network.setter
    def enable_es_public_network(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "enable_es_public_network", value)

    @property
    @pulumi.getter(name="enableKibanaPrivateDomainPublic")
    def enable_kibana_private_domain_public(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Kibana 是否开启私网地址公网解析。true：已开启私网地址公网解析false：未开启私网地址公网解析
        """
        return pulumi.get(self, "enable_kibana_private_domain_public")

    @enable_kibana_private_domain_public.setter
    def enable_kibana_private_domain_public(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "enable_kibana_private_domain_public", value)

    @property
    @pulumi.getter(name="enableKibanaPrivateNetwork")
    def enable_kibana_private_network(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Kibana 是否开启私网访问。true：默认值，已开启私网访问 false：未开启Kibana私网访问
        """
        return pulumi.get(self, "enable_kibana_private_network")

    @enable_kibana_private_network.setter
    def enable_kibana_private_network(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "enable_kibana_private_network", value)

    @property
    @pulumi.getter(name="enableKibanaPublicNetwork")
    def enable_kibana_public_network(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Kibana 是否开启了公网访问。true：已开启公网访问 false：未开启公网访问
        """
        return pulumi.get(self, "enable_kibana_public_network")

    @enable_kibana_public_network.setter
    def enable_kibana_public_network(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "enable_kibana_public_network", value)

    @property
    @pulumi.getter(name="esEip")
    def es_eip(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例所绑定的 EIP。
        """
        return pulumi.get(self, "es_eip")

    @es_eip.setter
    def es_eip(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "es_eip", value)

    @property
    @pulumi.getter(name="esEipId")
    def es_eip_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例所绑定的 EIP 的 ID。
        """
        return pulumi.get(self, "es_eip_id")

    @es_eip_id.setter
    def es_eip_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "es_eip_id", value)

    @property
    @pulumi.getter(name="esPrivateEndpoint")
    def es_private_endpoint(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例私网访问地址。
        """
        return pulumi.get(self, "es_private_endpoint")

    @es_private_endpoint.setter
    def es_private_endpoint(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "es_private_endpoint", value)

    @property
    @pulumi.getter(name="esPrivateIpAllowList")
    def es_private_ip_allow_list(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例私网地址访问白名单。同 ESPrivateIpWhitelist
        """
        return pulumi.get(self, "es_private_ip_allow_list")

    @es_private_ip_allow_list.setter
    def es_private_ip_allow_list(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "es_private_ip_allow_list", value)

    @property
    @pulumi.getter(name="esPrivateIpWhitelist")
    def es_private_ip_whitelist(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例私网地址访问白名单。
        """
        return pulumi.get(self, "es_private_ip_whitelist")

    @es_private_ip_whitelist.setter
    def es_private_ip_whitelist(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "es_private_ip_whitelist", value)

    @property
    @pulumi.getter(name="esPubBandwidth")
    def es_pub_bandwidth(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        ES公网带宽，单位:Mbps。
        """
        return pulumi.get(self, "es_pub_bandwidth")

    @es_pub_bandwidth.setter
    def es_pub_bandwidth(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "es_pub_bandwidth", value)

    @property
    @pulumi.getter(name="esPublicEndpoint")
    def es_public_endpoint(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例公网访问地址。
        """
        return pulumi.get(self, "es_public_endpoint")

    @es_public_endpoint.setter
    def es_public_endpoint(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "es_public_endpoint", value)

    @property
    @pulumi.getter(name="esPublicIpAllowList")
    def es_public_ip_allow_list(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例公网地址访问白名单。同 ESPublicIpWhitelist
        """
        return pulumi.get(self, "es_public_ip_allow_list")

    @es_public_ip_allow_list.setter
    def es_public_ip_allow_list(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "es_public_ip_allow_list", value)

    @property
    @pulumi.getter(name="esPublicIpWhitelist")
    def es_public_ip_whitelist(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例公网地址访问白名单。
        """
        return pulumi.get(self, "es_public_ip_whitelist")

    @es_public_ip_whitelist.setter
    def es_public_ip_whitelist(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "es_public_ip_whitelist", value)

    @property
    @pulumi.getter(name="expireDate")
    def expire_date(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        包年包月实例的付费过期时间。
        """
        return pulumi.get(self, "expire_date")

    @expire_date.setter
    def expire_date(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "expire_date", value)

    @property
    @pulumi.getter(name="instanceConfiguration")
    def instance_configuration(self) -> Optional[pulumi.Input['InstanceInstanceConfigurationArgs']]:
        """
        实例配置详情信息。
        """
        return pulumi.get(self, "instance_configuration")

    @instance_configuration.setter
    def instance_configuration(self, value: Optional[pulumi.Input['InstanceInstanceConfigurationArgs']]):
        pulumi.set(self, "instance_configuration", value)

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例 ID。
        """
        return pulumi.get(self, "instance_id")

    @instance_id.setter
    def instance_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "instance_id", value)

    @property
    @pulumi.getter(name="kibanaConfig")
    def kibana_config(self) -> Optional[pulumi.Input['InstanceKibanaConfigArgs']]:
        """
        Kibana 参数配置。
        """
        return pulumi.get(self, "kibana_config")

    @kibana_config.setter
    def kibana_config(self, value: Optional[pulumi.Input['InstanceKibanaConfigArgs']]):
        pulumi.set(self, "kibana_config", value)

    @property
    @pulumi.getter(name="kibanaEip")
    def kibana_eip(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Kibana 所绑定的 EIP。
        """
        return pulumi.get(self, "kibana_eip")

    @kibana_eip.setter
    def kibana_eip(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "kibana_eip", value)

    @property
    @pulumi.getter(name="kibanaEipId")
    def kibana_eip_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Kibana 所绑定的 EIP 的 ID。
        """
        return pulumi.get(self, "kibana_eip_id")

    @kibana_eip_id.setter
    def kibana_eip_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "kibana_eip_id", value)

    @property
    @pulumi.getter(name="kibanaPrivateDomain")
    def kibana_private_domain(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Kibana 私网访问地址。说明如果是历史实例，访问地址有可能是http(s)://kibana-***开头。
        """
        return pulumi.get(self, "kibana_private_domain")

    @kibana_private_domain.setter
    def kibana_private_domain(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "kibana_private_domain", value)

    @property
    @pulumi.getter(name="kibanaPrivateIpAllowList")
    def kibana_private_ip_allow_list(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Kibana 私网白名单。只有添加到白名单中的 IP 地址才可以访问可视化工具。同 KibanaPrivateIpWhitelist
        """
        return pulumi.get(self, "kibana_private_ip_allow_list")

    @kibana_private_ip_allow_list.setter
    def kibana_private_ip_allow_list(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "kibana_private_ip_allow_list", value)

    @property
    @pulumi.getter(name="kibanaPrivateIpWhitelist")
    def kibana_private_ip_whitelist(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Kibana 私网白名单。只有添加到白名单中的 IP 地址才可以访问可视化工具。说明Cerebro 和 Kibana 共用一套白名单。
        """
        return pulumi.get(self, "kibana_private_ip_whitelist")

    @kibana_private_ip_whitelist.setter
    def kibana_private_ip_whitelist(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "kibana_private_ip_whitelist", value)

    @property
    @pulumi.getter(name="kibanaPubBandwidth")
    def kibana_pub_bandwidth(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        Kibana公网带宽，单位: Mbps
        """
        return pulumi.get(self, "kibana_pub_bandwidth")

    @kibana_pub_bandwidth.setter
    def kibana_pub_bandwidth(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "kibana_pub_bandwidth", value)

    @property
    @pulumi.getter(name="kibanaPublicDomain")
    def kibana_public_domain(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Kibana 公网访问地址。说明如果是历史实例，访问地址有可能是http(s)://kibana-***开头。
        """
        return pulumi.get(self, "kibana_public_domain")

    @kibana_public_domain.setter
    def kibana_public_domain(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "kibana_public_domain", value)

    @property
    @pulumi.getter(name="kibanaPublicIpAllowList")
    def kibana_public_ip_allow_list(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Kibana 公网白名单。只有添加到白名单中的 IP 地址才可以访问可视化工具。同 KibanaPublicIpWhitelist
        """
        return pulumi.get(self, "kibana_public_ip_allow_list")

    @kibana_public_ip_allow_list.setter
    def kibana_public_ip_allow_list(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "kibana_public_ip_allow_list", value)

    @property
    @pulumi.getter(name="kibanaPublicIpWhitelist")
    def kibana_public_ip_whitelist(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Kibana 公网白名单。只有添加到白名单中的 IP 地址才可以访问可视化工具。说明Cerebro 和 Kibana 共用一套白名单
        """
        return pulumi.get(self, "kibana_public_ip_whitelist")

    @kibana_public_ip_whitelist.setter
    def kibana_public_ip_whitelist(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "kibana_public_ip_whitelist", value)

    @property
    @pulumi.getter(name="mainZoneId")
    def main_zone_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        主可用区
        """
        return pulumi.get(self, "main_zone_id")

    @main_zone_id.setter
    def main_zone_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "main_zone_id", value)

    @property
    @pulumi.getter(name="maintenanceDays")
    def maintenance_days(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        实例的可维护日期。
        """
        return pulumi.get(self, "maintenance_days")

    @maintenance_days.setter
    def maintenance_days(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "maintenance_days", value)

    @property
    @pulumi.getter(name="maintenanceTime")
    def maintenance_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例的可维护时间段。
        """
        return pulumi.get(self, "maintenance_time")

    @maintenance_time.setter
    def maintenance_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "maintenance_time", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例当前状态。
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter(name="subInstanceEnable")
    def sub_instance_enable(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        子实例开启情况。
        """
        return pulumi.get(self, "sub_instance_enable")

    @sub_instance_enable.setter
    def sub_instance_enable(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "sub_instance_enable", value)

    @property
    @pulumi.getter(name="subInstances")
    def sub_instances(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['InstanceSubInstanceArgs']]]]:
        return pulumi.get(self, "sub_instances")

    @sub_instances.setter
    def sub_instances(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['InstanceSubInstanceArgs']]]]):
        pulumi.set(self, "sub_instances", value)

    @property
    @pulumi.getter(name="supportColdNode")
    def support_cold_node(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        是否支持冷节点。
        """
        return pulumi.get(self, "support_cold_node")

    @support_cold_node.setter
    def support_cold_node(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "support_cold_node", value)

    @property
    @pulumi.getter(name="totalNodes")
    def total_nodes(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        实例的总节点数。
        """
        return pulumi.get(self, "total_nodes")

    @total_nodes.setter
    def total_nodes(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "total_nodes", value)

    @property
    @pulumi.getter(name="transferInfo")
    def transfer_info(self) -> Optional[pulumi.Input['InstanceTransferInfoArgs']]:
        """
        数据迁移任务信息。
        """
        return pulumi.get(self, "transfer_info")

    @transfer_info.setter
    def transfer_info(self, value: Optional[pulumi.Input['InstanceTransferInfoArgs']]):
        pulumi.set(self, "transfer_info", value)

    @property
    @pulumi.getter(name="userId")
    def user_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例所有者的用户 ID。
        """
        return pulumi.get(self, "user_id")

    @user_id.setter
    def user_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "user_id", value)


@pulumi.type_token("bytepluscc:escloud/instance:Instance")
class Instance(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 instance_configuration: Optional[pulumi.Input[Union['InstanceInstanceConfigurationArgs', 'InstanceInstanceConfigurationArgsDict']]] = None,
                 maintenance_days: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 maintenance_time: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        云搜索服务（Cloud Search）是提供的全托管一站式信息检索和分析平台，兼容 Elasticsearch、OpenSearch、Kibana、Dashboards、Cerebro 以及常用的开源插件，可应用于全文搜索、向量搜索、混合搜索、AI 搜索、时空检索等场景。使用云搜索服务，您可以实现一键部署、弹性扩缩、简化运维，快速构建日志分析、信息检索分析等实际业务。

        ## Import

        ```sh
        $ pulumi import bytepluscc:escloud/instance:Instance example "instance_id"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Union['InstanceInstanceConfigurationArgs', 'InstanceInstanceConfigurationArgsDict']] instance_configuration: 实例配置详情信息。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] maintenance_days: 实例的可维护日期。
        :param pulumi.Input[builtins.str] maintenance_time: 实例的可维护时间段。
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: InstanceArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        云搜索服务（Cloud Search）是提供的全托管一站式信息检索和分析平台，兼容 Elasticsearch、OpenSearch、Kibana、Dashboards、Cerebro 以及常用的开源插件，可应用于全文搜索、向量搜索、混合搜索、AI 搜索、时空检索等场景。使用云搜索服务，您可以实现一键部署、弹性扩缩、简化运维，快速构建日志分析、信息检索分析等实际业务。

        ## Import

        ```sh
        $ pulumi import bytepluscc:escloud/instance:Instance example "instance_id"
        ```

        :param str resource_name: The name of the resource.
        :param InstanceArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(InstanceArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 instance_configuration: Optional[pulumi.Input[Union['InstanceInstanceConfigurationArgs', 'InstanceInstanceConfigurationArgsDict']]] = None,
                 maintenance_days: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 maintenance_time: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = InstanceArgs.__new__(InstanceArgs)

            if instance_configuration is None and not opts.urn:
                raise TypeError("Missing required property 'instance_configuration'")
            __props__.__dict__["instance_configuration"] = instance_configuration
            __props__.__dict__["maintenance_days"] = maintenance_days
            __props__.__dict__["maintenance_time"] = maintenance_time
            __props__.__dict__["cerebro_enabled"] = None
            __props__.__dict__["cerebro_private_domain"] = None
            __props__.__dict__["cerebro_public_domain"] = None
            __props__.__dict__["charge_enabled"] = None
            __props__.__dict__["cluster_id"] = None
            __props__.__dict__["create_time"] = None
            __props__.__dict__["enable_es_private_domain_public"] = None
            __props__.__dict__["enable_es_private_network"] = None
            __props__.__dict__["enable_es_public_network"] = None
            __props__.__dict__["enable_kibana_private_domain_public"] = None
            __props__.__dict__["enable_kibana_private_network"] = None
            __props__.__dict__["enable_kibana_public_network"] = None
            __props__.__dict__["es_eip"] = None
            __props__.__dict__["es_eip_id"] = None
            __props__.__dict__["es_private_endpoint"] = None
            __props__.__dict__["es_private_ip_allow_list"] = None
            __props__.__dict__["es_private_ip_whitelist"] = None
            __props__.__dict__["es_pub_bandwidth"] = None
            __props__.__dict__["es_public_endpoint"] = None
            __props__.__dict__["es_public_ip_allow_list"] = None
            __props__.__dict__["es_public_ip_whitelist"] = None
            __props__.__dict__["expire_date"] = None
            __props__.__dict__["instance_id"] = None
            __props__.__dict__["kibana_config"] = None
            __props__.__dict__["kibana_eip"] = None
            __props__.__dict__["kibana_eip_id"] = None
            __props__.__dict__["kibana_private_domain"] = None
            __props__.__dict__["kibana_private_ip_allow_list"] = None
            __props__.__dict__["kibana_private_ip_whitelist"] = None
            __props__.__dict__["kibana_pub_bandwidth"] = None
            __props__.__dict__["kibana_public_domain"] = None
            __props__.__dict__["kibana_public_ip_allow_list"] = None
            __props__.__dict__["kibana_public_ip_whitelist"] = None
            __props__.__dict__["main_zone_id"] = None
            __props__.__dict__["status"] = None
            __props__.__dict__["sub_instance_enable"] = None
            __props__.__dict__["sub_instances"] = None
            __props__.__dict__["support_cold_node"] = None
            __props__.__dict__["total_nodes"] = None
            __props__.__dict__["transfer_info"] = None
            __props__.__dict__["user_id"] = None
        super(Instance, __self__).__init__(
            'bytepluscc:escloud/instance:Instance',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            cerebro_enabled: Optional[pulumi.Input[builtins.bool]] = None,
            cerebro_private_domain: Optional[pulumi.Input[builtins.str]] = None,
            cerebro_public_domain: Optional[pulumi.Input[builtins.str]] = None,
            charge_enabled: Optional[pulumi.Input[builtins.bool]] = None,
            cluster_id: Optional[pulumi.Input[builtins.str]] = None,
            create_time: Optional[pulumi.Input[builtins.str]] = None,
            enable_es_private_domain_public: Optional[pulumi.Input[builtins.bool]] = None,
            enable_es_private_network: Optional[pulumi.Input[builtins.bool]] = None,
            enable_es_public_network: Optional[pulumi.Input[builtins.bool]] = None,
            enable_kibana_private_domain_public: Optional[pulumi.Input[builtins.bool]] = None,
            enable_kibana_private_network: Optional[pulumi.Input[builtins.bool]] = None,
            enable_kibana_public_network: Optional[pulumi.Input[builtins.bool]] = None,
            es_eip: Optional[pulumi.Input[builtins.str]] = None,
            es_eip_id: Optional[pulumi.Input[builtins.str]] = None,
            es_private_endpoint: Optional[pulumi.Input[builtins.str]] = None,
            es_private_ip_allow_list: Optional[pulumi.Input[builtins.str]] = None,
            es_private_ip_whitelist: Optional[pulumi.Input[builtins.str]] = None,
            es_pub_bandwidth: Optional[pulumi.Input[builtins.int]] = None,
            es_public_endpoint: Optional[pulumi.Input[builtins.str]] = None,
            es_public_ip_allow_list: Optional[pulumi.Input[builtins.str]] = None,
            es_public_ip_whitelist: Optional[pulumi.Input[builtins.str]] = None,
            expire_date: Optional[pulumi.Input[builtins.str]] = None,
            instance_configuration: Optional[pulumi.Input[Union['InstanceInstanceConfigurationArgs', 'InstanceInstanceConfigurationArgsDict']]] = None,
            instance_id: Optional[pulumi.Input[builtins.str]] = None,
            kibana_config: Optional[pulumi.Input[Union['InstanceKibanaConfigArgs', 'InstanceKibanaConfigArgsDict']]] = None,
            kibana_eip: Optional[pulumi.Input[builtins.str]] = None,
            kibana_eip_id: Optional[pulumi.Input[builtins.str]] = None,
            kibana_private_domain: Optional[pulumi.Input[builtins.str]] = None,
            kibana_private_ip_allow_list: Optional[pulumi.Input[builtins.str]] = None,
            kibana_private_ip_whitelist: Optional[pulumi.Input[builtins.str]] = None,
            kibana_pub_bandwidth: Optional[pulumi.Input[builtins.int]] = None,
            kibana_public_domain: Optional[pulumi.Input[builtins.str]] = None,
            kibana_public_ip_allow_list: Optional[pulumi.Input[builtins.str]] = None,
            kibana_public_ip_whitelist: Optional[pulumi.Input[builtins.str]] = None,
            main_zone_id: Optional[pulumi.Input[builtins.str]] = None,
            maintenance_days: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
            maintenance_time: Optional[pulumi.Input[builtins.str]] = None,
            status: Optional[pulumi.Input[builtins.str]] = None,
            sub_instance_enable: Optional[pulumi.Input[builtins.str]] = None,
            sub_instances: Optional[pulumi.Input[Sequence[pulumi.Input[Union['InstanceSubInstanceArgs', 'InstanceSubInstanceArgsDict']]]]] = None,
            support_cold_node: Optional[pulumi.Input[builtins.bool]] = None,
            total_nodes: Optional[pulumi.Input[builtins.int]] = None,
            transfer_info: Optional[pulumi.Input[Union['InstanceTransferInfoArgs', 'InstanceTransferInfoArgsDict']]] = None,
            user_id: Optional[pulumi.Input[builtins.str]] = None) -> 'Instance':
        """
        Get an existing Instance resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.bool] cerebro_enabled: 是否开启 cerebro。true：开启 cerebrofalse：不开启 cerebro
        :param pulumi.Input[builtins.str] cerebro_private_domain: cerebro 私网访问地址。说明Cerebro 和 Kibana 共享域名。如果是历史实例，访问地址有可能是http(s)://kibana-***开头
        :param pulumi.Input[builtins.str] cerebro_public_domain: erebro 公网访问地址。说明Cerebro 和 Kibana 共享域名。如果是历史实例，访问地址有可能是http(s)://kibana-***开头。
        :param pulumi.Input[builtins.bool] charge_enabled: 实例是否开启了计费。取值说明如下：true：已开启计费false：未开启计费
        :param pulumi.Input[builtins.str] cluster_id: 实例所属集群的 ID。
        :param pulumi.Input[builtins.str] create_time: 实例的创建时间。
        :param pulumi.Input[builtins.bool] enable_es_private_domain_public: 实例是否开启私网地址公网解析。true：已开启私网地址公网解析false：未开启私网地址公网解析
        :param pulumi.Input[builtins.bool] enable_es_private_network: 实例是否开启了私网访问。true：默认值，开启私网访问false：未开启私网访问
        :param pulumi.Input[builtins.bool] enable_es_public_network: 实例是否开启了公网访问。true：已开启公网访问false：未开启公网访问
        :param pulumi.Input[builtins.bool] enable_kibana_private_domain_public: Kibana 是否开启私网地址公网解析。true：已开启私网地址公网解析false：未开启私网地址公网解析
        :param pulumi.Input[builtins.bool] enable_kibana_private_network: Kibana 是否开启私网访问。true：默认值，已开启私网访问 false：未开启Kibana私网访问
        :param pulumi.Input[builtins.bool] enable_kibana_public_network: Kibana 是否开启了公网访问。true：已开启公网访问 false：未开启公网访问
        :param pulumi.Input[builtins.str] es_eip: 实例所绑定的 EIP。
        :param pulumi.Input[builtins.str] es_eip_id: 实例所绑定的 EIP 的 ID。
        :param pulumi.Input[builtins.str] es_private_endpoint: 实例私网访问地址。
        :param pulumi.Input[builtins.str] es_private_ip_allow_list: 实例私网地址访问白名单。同 ESPrivateIpWhitelist
        :param pulumi.Input[builtins.str] es_private_ip_whitelist: 实例私网地址访问白名单。
        :param pulumi.Input[builtins.int] es_pub_bandwidth: ES公网带宽，单位:Mbps。
        :param pulumi.Input[builtins.str] es_public_endpoint: 实例公网访问地址。
        :param pulumi.Input[builtins.str] es_public_ip_allow_list: 实例公网地址访问白名单。同 ESPublicIpWhitelist
        :param pulumi.Input[builtins.str] es_public_ip_whitelist: 实例公网地址访问白名单。
        :param pulumi.Input[builtins.str] expire_date: 包年包月实例的付费过期时间。
        :param pulumi.Input[Union['InstanceInstanceConfigurationArgs', 'InstanceInstanceConfigurationArgsDict']] instance_configuration: 实例配置详情信息。
        :param pulumi.Input[builtins.str] instance_id: 实例 ID。
        :param pulumi.Input[Union['InstanceKibanaConfigArgs', 'InstanceKibanaConfigArgsDict']] kibana_config: Kibana 参数配置。
        :param pulumi.Input[builtins.str] kibana_eip: Kibana 所绑定的 EIP。
        :param pulumi.Input[builtins.str] kibana_eip_id: Kibana 所绑定的 EIP 的 ID。
        :param pulumi.Input[builtins.str] kibana_private_domain: Kibana 私网访问地址。说明如果是历史实例，访问地址有可能是http(s)://kibana-***开头。
        :param pulumi.Input[builtins.str] kibana_private_ip_allow_list: Kibana 私网白名单。只有添加到白名单中的 IP 地址才可以访问可视化工具。同 KibanaPrivateIpWhitelist
        :param pulumi.Input[builtins.str] kibana_private_ip_whitelist: Kibana 私网白名单。只有添加到白名单中的 IP 地址才可以访问可视化工具。说明Cerebro 和 Kibana 共用一套白名单。
        :param pulumi.Input[builtins.int] kibana_pub_bandwidth: Kibana公网带宽，单位: Mbps
        :param pulumi.Input[builtins.str] kibana_public_domain: Kibana 公网访问地址。说明如果是历史实例，访问地址有可能是http(s)://kibana-***开头。
        :param pulumi.Input[builtins.str] kibana_public_ip_allow_list: Kibana 公网白名单。只有添加到白名单中的 IP 地址才可以访问可视化工具。同 KibanaPublicIpWhitelist
        :param pulumi.Input[builtins.str] kibana_public_ip_whitelist: Kibana 公网白名单。只有添加到白名单中的 IP 地址才可以访问可视化工具。说明Cerebro 和 Kibana 共用一套白名单
        :param pulumi.Input[builtins.str] main_zone_id: 主可用区
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] maintenance_days: 实例的可维护日期。
        :param pulumi.Input[builtins.str] maintenance_time: 实例的可维护时间段。
        :param pulumi.Input[builtins.str] status: 实例当前状态。
        :param pulumi.Input[builtins.str] sub_instance_enable: 子实例开启情况。
        :param pulumi.Input[builtins.bool] support_cold_node: 是否支持冷节点。
        :param pulumi.Input[builtins.int] total_nodes: 实例的总节点数。
        :param pulumi.Input[Union['InstanceTransferInfoArgs', 'InstanceTransferInfoArgsDict']] transfer_info: 数据迁移任务信息。
        :param pulumi.Input[builtins.str] user_id: 实例所有者的用户 ID。
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _InstanceState.__new__(_InstanceState)

        __props__.__dict__["cerebro_enabled"] = cerebro_enabled
        __props__.__dict__["cerebro_private_domain"] = cerebro_private_domain
        __props__.__dict__["cerebro_public_domain"] = cerebro_public_domain
        __props__.__dict__["charge_enabled"] = charge_enabled
        __props__.__dict__["cluster_id"] = cluster_id
        __props__.__dict__["create_time"] = create_time
        __props__.__dict__["enable_es_private_domain_public"] = enable_es_private_domain_public
        __props__.__dict__["enable_es_private_network"] = enable_es_private_network
        __props__.__dict__["enable_es_public_network"] = enable_es_public_network
        __props__.__dict__["enable_kibana_private_domain_public"] = enable_kibana_private_domain_public
        __props__.__dict__["enable_kibana_private_network"] = enable_kibana_private_network
        __props__.__dict__["enable_kibana_public_network"] = enable_kibana_public_network
        __props__.__dict__["es_eip"] = es_eip
        __props__.__dict__["es_eip_id"] = es_eip_id
        __props__.__dict__["es_private_endpoint"] = es_private_endpoint
        __props__.__dict__["es_private_ip_allow_list"] = es_private_ip_allow_list
        __props__.__dict__["es_private_ip_whitelist"] = es_private_ip_whitelist
        __props__.__dict__["es_pub_bandwidth"] = es_pub_bandwidth
        __props__.__dict__["es_public_endpoint"] = es_public_endpoint
        __props__.__dict__["es_public_ip_allow_list"] = es_public_ip_allow_list
        __props__.__dict__["es_public_ip_whitelist"] = es_public_ip_whitelist
        __props__.__dict__["expire_date"] = expire_date
        __props__.__dict__["instance_configuration"] = instance_configuration
        __props__.__dict__["instance_id"] = instance_id
        __props__.__dict__["kibana_config"] = kibana_config
        __props__.__dict__["kibana_eip"] = kibana_eip
        __props__.__dict__["kibana_eip_id"] = kibana_eip_id
        __props__.__dict__["kibana_private_domain"] = kibana_private_domain
        __props__.__dict__["kibana_private_ip_allow_list"] = kibana_private_ip_allow_list
        __props__.__dict__["kibana_private_ip_whitelist"] = kibana_private_ip_whitelist
        __props__.__dict__["kibana_pub_bandwidth"] = kibana_pub_bandwidth
        __props__.__dict__["kibana_public_domain"] = kibana_public_domain
        __props__.__dict__["kibana_public_ip_allow_list"] = kibana_public_ip_allow_list
        __props__.__dict__["kibana_public_ip_whitelist"] = kibana_public_ip_whitelist
        __props__.__dict__["main_zone_id"] = main_zone_id
        __props__.__dict__["maintenance_days"] = maintenance_days
        __props__.__dict__["maintenance_time"] = maintenance_time
        __props__.__dict__["status"] = status
        __props__.__dict__["sub_instance_enable"] = sub_instance_enable
        __props__.__dict__["sub_instances"] = sub_instances
        __props__.__dict__["support_cold_node"] = support_cold_node
        __props__.__dict__["total_nodes"] = total_nodes
        __props__.__dict__["transfer_info"] = transfer_info
        __props__.__dict__["user_id"] = user_id
        return Instance(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="cerebroEnabled")
    def cerebro_enabled(self) -> pulumi.Output[builtins.bool]:
        """
        是否开启 cerebro。true：开启 cerebrofalse：不开启 cerebro
        """
        return pulumi.get(self, "cerebro_enabled")

    @property
    @pulumi.getter(name="cerebroPrivateDomain")
    def cerebro_private_domain(self) -> pulumi.Output[builtins.str]:
        """
        cerebro 私网访问地址。说明Cerebro 和 Kibana 共享域名。如果是历史实例，访问地址有可能是http(s)://kibana-***开头
        """
        return pulumi.get(self, "cerebro_private_domain")

    @property
    @pulumi.getter(name="cerebroPublicDomain")
    def cerebro_public_domain(self) -> pulumi.Output[builtins.str]:
        """
        erebro 公网访问地址。说明Cerebro 和 Kibana 共享域名。如果是历史实例，访问地址有可能是http(s)://kibana-***开头。
        """
        return pulumi.get(self, "cerebro_public_domain")

    @property
    @pulumi.getter(name="chargeEnabled")
    def charge_enabled(self) -> pulumi.Output[builtins.bool]:
        """
        实例是否开启了计费。取值说明如下：true：已开启计费false：未开启计费
        """
        return pulumi.get(self, "charge_enabled")

    @property
    @pulumi.getter(name="clusterId")
    def cluster_id(self) -> pulumi.Output[builtins.str]:
        """
        实例所属集群的 ID。
        """
        return pulumi.get(self, "cluster_id")

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> pulumi.Output[builtins.str]:
        """
        实例的创建时间。
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter(name="enableEsPrivateDomainPublic")
    def enable_es_private_domain_public(self) -> pulumi.Output[builtins.bool]:
        """
        实例是否开启私网地址公网解析。true：已开启私网地址公网解析false：未开启私网地址公网解析
        """
        return pulumi.get(self, "enable_es_private_domain_public")

    @property
    @pulumi.getter(name="enableEsPrivateNetwork")
    def enable_es_private_network(self) -> pulumi.Output[builtins.bool]:
        """
        实例是否开启了私网访问。true：默认值，开启私网访问false：未开启私网访问
        """
        return pulumi.get(self, "enable_es_private_network")

    @property
    @pulumi.getter(name="enableEsPublicNetwork")
    def enable_es_public_network(self) -> pulumi.Output[builtins.bool]:
        """
        实例是否开启了公网访问。true：已开启公网访问false：未开启公网访问
        """
        return pulumi.get(self, "enable_es_public_network")

    @property
    @pulumi.getter(name="enableKibanaPrivateDomainPublic")
    def enable_kibana_private_domain_public(self) -> pulumi.Output[builtins.bool]:
        """
        Kibana 是否开启私网地址公网解析。true：已开启私网地址公网解析false：未开启私网地址公网解析
        """
        return pulumi.get(self, "enable_kibana_private_domain_public")

    @property
    @pulumi.getter(name="enableKibanaPrivateNetwork")
    def enable_kibana_private_network(self) -> pulumi.Output[builtins.bool]:
        """
        Kibana 是否开启私网访问。true：默认值，已开启私网访问 false：未开启Kibana私网访问
        """
        return pulumi.get(self, "enable_kibana_private_network")

    @property
    @pulumi.getter(name="enableKibanaPublicNetwork")
    def enable_kibana_public_network(self) -> pulumi.Output[builtins.bool]:
        """
        Kibana 是否开启了公网访问。true：已开启公网访问 false：未开启公网访问
        """
        return pulumi.get(self, "enable_kibana_public_network")

    @property
    @pulumi.getter(name="esEip")
    def es_eip(self) -> pulumi.Output[builtins.str]:
        """
        实例所绑定的 EIP。
        """
        return pulumi.get(self, "es_eip")

    @property
    @pulumi.getter(name="esEipId")
    def es_eip_id(self) -> pulumi.Output[builtins.str]:
        """
        实例所绑定的 EIP 的 ID。
        """
        return pulumi.get(self, "es_eip_id")

    @property
    @pulumi.getter(name="esPrivateEndpoint")
    def es_private_endpoint(self) -> pulumi.Output[builtins.str]:
        """
        实例私网访问地址。
        """
        return pulumi.get(self, "es_private_endpoint")

    @property
    @pulumi.getter(name="esPrivateIpAllowList")
    def es_private_ip_allow_list(self) -> pulumi.Output[builtins.str]:
        """
        实例私网地址访问白名单。同 ESPrivateIpWhitelist
        """
        return pulumi.get(self, "es_private_ip_allow_list")

    @property
    @pulumi.getter(name="esPrivateIpWhitelist")
    def es_private_ip_whitelist(self) -> pulumi.Output[builtins.str]:
        """
        实例私网地址访问白名单。
        """
        return pulumi.get(self, "es_private_ip_whitelist")

    @property
    @pulumi.getter(name="esPubBandwidth")
    def es_pub_bandwidth(self) -> pulumi.Output[builtins.int]:
        """
        ES公网带宽，单位:Mbps。
        """
        return pulumi.get(self, "es_pub_bandwidth")

    @property
    @pulumi.getter(name="esPublicEndpoint")
    def es_public_endpoint(self) -> pulumi.Output[builtins.str]:
        """
        实例公网访问地址。
        """
        return pulumi.get(self, "es_public_endpoint")

    @property
    @pulumi.getter(name="esPublicIpAllowList")
    def es_public_ip_allow_list(self) -> pulumi.Output[builtins.str]:
        """
        实例公网地址访问白名单。同 ESPublicIpWhitelist
        """
        return pulumi.get(self, "es_public_ip_allow_list")

    @property
    @pulumi.getter(name="esPublicIpWhitelist")
    def es_public_ip_whitelist(self) -> pulumi.Output[builtins.str]:
        """
        实例公网地址访问白名单。
        """
        return pulumi.get(self, "es_public_ip_whitelist")

    @property
    @pulumi.getter(name="expireDate")
    def expire_date(self) -> pulumi.Output[builtins.str]:
        """
        包年包月实例的付费过期时间。
        """
        return pulumi.get(self, "expire_date")

    @property
    @pulumi.getter(name="instanceConfiguration")
    def instance_configuration(self) -> pulumi.Output['outputs.InstanceInstanceConfiguration']:
        """
        实例配置详情信息。
        """
        return pulumi.get(self, "instance_configuration")

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> pulumi.Output[builtins.str]:
        """
        实例 ID。
        """
        return pulumi.get(self, "instance_id")

    @property
    @pulumi.getter(name="kibanaConfig")
    def kibana_config(self) -> pulumi.Output['outputs.InstanceKibanaConfig']:
        """
        Kibana 参数配置。
        """
        return pulumi.get(self, "kibana_config")

    @property
    @pulumi.getter(name="kibanaEip")
    def kibana_eip(self) -> pulumi.Output[builtins.str]:
        """
        Kibana 所绑定的 EIP。
        """
        return pulumi.get(self, "kibana_eip")

    @property
    @pulumi.getter(name="kibanaEipId")
    def kibana_eip_id(self) -> pulumi.Output[builtins.str]:
        """
        Kibana 所绑定的 EIP 的 ID。
        """
        return pulumi.get(self, "kibana_eip_id")

    @property
    @pulumi.getter(name="kibanaPrivateDomain")
    def kibana_private_domain(self) -> pulumi.Output[builtins.str]:
        """
        Kibana 私网访问地址。说明如果是历史实例，访问地址有可能是http(s)://kibana-***开头。
        """
        return pulumi.get(self, "kibana_private_domain")

    @property
    @pulumi.getter(name="kibanaPrivateIpAllowList")
    def kibana_private_ip_allow_list(self) -> pulumi.Output[builtins.str]:
        """
        Kibana 私网白名单。只有添加到白名单中的 IP 地址才可以访问可视化工具。同 KibanaPrivateIpWhitelist
        """
        return pulumi.get(self, "kibana_private_ip_allow_list")

    @property
    @pulumi.getter(name="kibanaPrivateIpWhitelist")
    def kibana_private_ip_whitelist(self) -> pulumi.Output[builtins.str]:
        """
        Kibana 私网白名单。只有添加到白名单中的 IP 地址才可以访问可视化工具。说明Cerebro 和 Kibana 共用一套白名单。
        """
        return pulumi.get(self, "kibana_private_ip_whitelist")

    @property
    @pulumi.getter(name="kibanaPubBandwidth")
    def kibana_pub_bandwidth(self) -> pulumi.Output[builtins.int]:
        """
        Kibana公网带宽，单位: Mbps
        """
        return pulumi.get(self, "kibana_pub_bandwidth")

    @property
    @pulumi.getter(name="kibanaPublicDomain")
    def kibana_public_domain(self) -> pulumi.Output[builtins.str]:
        """
        Kibana 公网访问地址。说明如果是历史实例，访问地址有可能是http(s)://kibana-***开头。
        """
        return pulumi.get(self, "kibana_public_domain")

    @property
    @pulumi.getter(name="kibanaPublicIpAllowList")
    def kibana_public_ip_allow_list(self) -> pulumi.Output[builtins.str]:
        """
        Kibana 公网白名单。只有添加到白名单中的 IP 地址才可以访问可视化工具。同 KibanaPublicIpWhitelist
        """
        return pulumi.get(self, "kibana_public_ip_allow_list")

    @property
    @pulumi.getter(name="kibanaPublicIpWhitelist")
    def kibana_public_ip_whitelist(self) -> pulumi.Output[builtins.str]:
        """
        Kibana 公网白名单。只有添加到白名单中的 IP 地址才可以访问可视化工具。说明Cerebro 和 Kibana 共用一套白名单
        """
        return pulumi.get(self, "kibana_public_ip_whitelist")

    @property
    @pulumi.getter(name="mainZoneId")
    def main_zone_id(self) -> pulumi.Output[builtins.str]:
        """
        主可用区
        """
        return pulumi.get(self, "main_zone_id")

    @property
    @pulumi.getter(name="maintenanceDays")
    def maintenance_days(self) -> pulumi.Output[Sequence[builtins.str]]:
        """
        实例的可维护日期。
        """
        return pulumi.get(self, "maintenance_days")

    @property
    @pulumi.getter(name="maintenanceTime")
    def maintenance_time(self) -> pulumi.Output[builtins.str]:
        """
        实例的可维护时间段。
        """
        return pulumi.get(self, "maintenance_time")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[builtins.str]:
        """
        实例当前状态。
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="subInstanceEnable")
    def sub_instance_enable(self) -> pulumi.Output[builtins.str]:
        """
        子实例开启情况。
        """
        return pulumi.get(self, "sub_instance_enable")

    @property
    @pulumi.getter(name="subInstances")
    def sub_instances(self) -> pulumi.Output[Sequence['outputs.InstanceSubInstance']]:
        return pulumi.get(self, "sub_instances")

    @property
    @pulumi.getter(name="supportColdNode")
    def support_cold_node(self) -> pulumi.Output[builtins.bool]:
        """
        是否支持冷节点。
        """
        return pulumi.get(self, "support_cold_node")

    @property
    @pulumi.getter(name="totalNodes")
    def total_nodes(self) -> pulumi.Output[builtins.int]:
        """
        实例的总节点数。
        """
        return pulumi.get(self, "total_nodes")

    @property
    @pulumi.getter(name="transferInfo")
    def transfer_info(self) -> pulumi.Output['outputs.InstanceTransferInfo']:
        """
        数据迁移任务信息。
        """
        return pulumi.get(self, "transfer_info")

    @property
    @pulumi.getter(name="userId")
    def user_id(self) -> pulumi.Output[builtins.str]:
        """
        实例所有者的用户 ID。
        """
        return pulumi.get(self, "user_id")

